AlphaWsStreams

Struct AlphaWsStreams 

pub struct AlphaWsStreams {}
Represents the Alpha WebSocket Streams client for interacting with the Binance Alpha WebSocket Streams.

This struct provides methods to create WebSocket Streams clients for production environments.

Implementations

Source

impl AlphaWsStreams

pub fn from_config( config: ConfigurationWebsocketStreams, ) -> WebsocketStreamsHandle

Creates a WebSocket streams client configured with the given settings.

If no WS URL is specified in the configuration, defaults to the production Alpha WebSocket Streams URL.

Arguments
  • config - Configuration for the WebSocket streams client
Returns

A new WebSocket streams client configured with the provided settings

pub fn production( config: ConfigurationWebsocketStreams, ) -> WebsocketStreamsHandle

Creates a WebSocket streams client configured for the production environment.

Arguments
  • config - Configuration for the WebSocket streams client
Returns

A new WebSocket streams client configured for the production environment