pub struct SendQuoteRequestParamsBuilder { /* private fields */ }Expand description
Builder for SendQuoteRequestParams.
Implementations
Sourceimpl SendQuoteRequestParamsBuilder
impl SendQuoteRequestParamsBuilder
Sourcepub fn from_asset<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn from_asset<VALUE: Into<String>>(self, value: VALUE) -> Self
The from_asset parameter.
This field is **required.
Sourcepub fn to_asset<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn to_asset<VALUE: Into<String>>(self, value: VALUE) -> Self
The to_asset parameter.
This field is **required.
Sourcepub fn from_amount<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn from_amount<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
When specified, it is the amount you will be debited after the conversion
This field is **optional.
Sourcepub fn to_amount<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn to_amount<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
When specified, it is the amount you will be credited after the conversion
This field is **optional.
Sourcepub fn wallet_type<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn wallet_type<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
It is to choose which wallet of assets. The wallet selection is SPOT, FUNDING and EARN. Combination of wallet is supported i.e. SPOT_FUNDING, FUNDING_EARN, SPOT_FUNDING_EARN or SPOT_EARN Default is SPOT.
This field is **optional.
Sourcepub fn valid_time<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn valid_time<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
10s, 30s, 1m, default 10s
This field is **optional.
Sourcepub fn recv_window<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
pub fn recv_window<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
The value cannot be greater than 60000
This field is **optional.
Sourcepub fn build(self) -> Result<SendQuoteRequestParams, ParamBuildError>
pub fn build(self) -> Result<SendQuoteRequestParams, ParamBuildError>