SendQuoteRequestParams

Struct SendQuoteRequestParams 

pub struct SendQuoteRequestParams {
    pub from_asset: String,
    pub to_asset: String,
    pub from_amount: Option<Decimal>,
    pub to_amount: Option<Decimal>,
    pub wallet_type: Option<String>,
    pub valid_time: Option<String>,
    pub recv_window: Option<i64>,
}
Request parameters for the [send_quote_request] operation.

This struct holds all of the inputs you can pass when calling send_quote_request.

Fields

from_asset: String

The from_asset parameter.

This field is **required.

to_asset: String

The to_asset parameter.

This field is **required.

from_amount: Option<Decimal>

When specified, it is the amount you will be debited after the conversion

This field is **optional.

to_amount: Option<Decimal>

When specified, it is the amount you will be credited after the conversion

This field is **optional.

wallet_type: Option<String>

It is to choose which wallet of assets. The wallet selection is SPOT, FUNDING and EARN. Combination of wallet is supported i.e. SPOT_FUNDING, FUNDING_EARN, SPOT_FUNDING_EARN or SPOT_EARN Default is SPOT.

This field is **optional.

valid_time: Option<String>

10s, 30s, 1m, default 10s

This field is **optional.

recv_window: Option<i64>

The value cannot be greater than 60000

This field is **optional.

Implementations

Source

impl SendQuoteRequestParams

pub fn builder( from_asset: String, to_asset: String, ) -> SendQuoteRequestParamsBuilder

Create a builder for [send_quote_request].

Required parameters:

  • from_asset — String
  • to_asset — String