pub struct QueryMarginInterestRateHistoryParams {
pub asset: String,
pub vip_level: Option<i64>,
pub start_time: Option<i64>,
pub end_time: Option<i64>,
pub recv_window: Option<i64>,
}Expand description
Request parameters for the [query_margin_interest_rate_history] operation.
This struct holds all of the inputs you can pass when calling
query_margin_interest_rate_history.
Fields
asset: StringThe asset parameter.
This field is **required.
vip_level: Option<i64>User’s current specific margin data will be returned if vipLevel is omitted
This field is **optional.
start_time: Option<i64>Only supports querying data from the past 90 days.
This field is **optional.
end_time: Option<i64>The end_time parameter.
This field is **optional.
recv_window: Option<i64>No more than 60000
This field is **optional.
Implementations
Sourceimpl QueryMarginInterestRateHistoryParams
impl QueryMarginInterestRateHistoryParams
Sourcepub fn builder(asset: String) -> QueryMarginInterestRateHistoryParamsBuilder
pub fn builder(asset: String) -> QueryMarginInterestRateHistoryParamsBuilder
Create a builder for [query_margin_interest_rate_history].
Required parameters:
asset— String