ExecutionReport

Struct ExecutionReport 

pub struct ExecutionReport {
Show 50 fields pub e_uppercase: Option<i64>, pub s: Option<String>, pub c: Option<String>, pub s_uppercase: Option<String>, pub o: Option<String>, pub f: Option<String>, pub q: Option<String>, pub p: Option<String>, pub p_uppercase: Option<String>, pub f_uppercase: Option<String>, pub g: Option<i64>, pub c_uppercase: Option<String>, pub x: Option<String>, pub x_uppercase: Option<String>, pub r: Option<String>, pub i: Option<i64>, pub l: Option<String>, pub z: Option<String>, pub l_uppercase: Option<String>, pub n: Option<String>, pub n_uppercase: Option<String>, pub t_uppercase: Option<i64>, pub t: Option<i64>, pub i_uppercase: Option<i64>, pub w: Option<bool>, pub m: Option<bool>, pub m_uppercase: Option<bool>, pub o_uppercase: Option<i64>, pub z_uppercase: Option<String>, pub y_uppercase: Option<String>, pub q_uppercase: Option<String>, pub w_uppercase: Option<i64>, pub v_uppercase: Option<String>, pub d: Option<String>, pub d_uppercase: Option<String>, pub j: Option<String>, pub j_uppercase: Option<String>, pub v: Option<String>, pub a_uppercase: Option<String>, pub b_uppercase: Option<String>, pub u: Option<String>, pub u_uppercase: Option<String>, pub cs: Option<String>, pub pl: Option<String>, pub p_l: Option<String>, pub p_y: Option<String>, pub b: Option<String>, pub a: Option<String>, pub k: Option<String>, pub u_s: Option<bool>,
}

Fields

e_uppercase: Option<i64>

Event time

s: Option<String>

Symbol

c: Option<String>

Client order ID

s_uppercase: Option<String>

Side

o: Option<String>

Order type

f: Option<String>

Time in force

q: Option<String>

Order quantity

p: Option<String>

Order price

p_uppercase: Option<String>

Stop price

f_uppercase: Option<String>

Iceberg quantity

g: Option<i64>

OrderListId

c_uppercase: Option<String>

Original client order ID; This is the ID of the order being canceled

x: Option<String>

Current execution type

x_uppercase: Option<String>

Current order status

r: Option<String>

Order reject reason; will be an error code.

i: Option<i64>

Order ID

l: Option<String>

Last executed quantity

z: Option<String>

Cumulative filled quantity

l_uppercase: Option<String>

Last executed price

n: Option<String>

Commission amount

n_uppercase: Option<String>

Commission asset

t_uppercase: Option<i64>

Transaction time

t: Option<i64>

Trade ID

i_uppercase: Option<i64>

Ignore

w: Option<bool>

Is the order on the book?

m: Option<bool>

Is this trade the maker side?

m_uppercase: Option<bool>

Ignore

o_uppercase: Option<i64>

Order creation time

z_uppercase: Option<String>

Cumulative quote asset transacted quantity

y_uppercase: Option<String>

Last quote asset transacted quantity (i.e. lastPrice * lastQty)

q_uppercase: Option<String>

Quote Order Quantity

w_uppercase: Option<i64>

Working Time; This is only visible if the order has been placed on the book.

v_uppercase: Option<String>

selfTradePreventionMode

d: Option<String>

Trailing Delta; This is only visible if the order was a trailing stop order.

d_uppercase: Option<String>

Trailing Time

j: Option<String>

Strategy Id

j_uppercase: Option<String>

Strategy Type

v: Option<String>

Prevented Match Id

a_uppercase: Option<String>

Prevented Quantity

b_uppercase: Option<String>

Last Prevented Quantity

u: Option<String>

Trade Group Id

u_uppercase: Option<String>

Counter Order Id

cs: Option<String>

Counter Symbol

pl: Option<String>

Prevented Execution Quantity

p_l: Option<String>

Prevented Execution Price

p_y: Option<String>

Prevented Execution Quote Qty

b: Option<String>

Match Type

a: Option<String>

Allocation ID

k: Option<String>

Working Floor

u_s: Option<bool>

UsedSor

Implementations