pub struct HashrateResaleListParams {
pub page_index: Option<i64>,
pub page_size: Option<i64>,
pub recv_window: Option<i64>,
}Expand description
Request parameters for the [hashrate_resale_list] operation.
This struct holds all of the inputs you can pass when calling
hashrate_resale_list.
Fields
page_index: Option<i64>Page number, empty default first page, starting from 1
This field is **optional.
page_size: Option<i64>Min 10,Max 200
This field is **optional.
recv_window: Option<i64>The recv_window parameter.
This field is **optional.
Implementations
Sourceimpl HashrateResaleListParams
impl HashrateResaleListParams
Sourcepub fn builder() -> HashrateResaleListParamsBuilder
pub fn builder() -> HashrateResaleListParamsBuilder
Create a builder for [hashrate_resale_list].