pub struct MiningAccountEarningParams {
pub algo: String,
pub start_date: Option<i64>,
pub end_date: Option<i64>,
pub page_index: Option<i64>,
pub page_size: Option<i64>,
pub recv_window: Option<i64>,
}Expand description
Request parameters for the [mining_account_earning] operation.
This struct holds all of the inputs you can pass when calling
mining_account_earning.
Fields
algo: StringAlgorithm(sha256) sha256
This field is **required.
start_date: Option<i64>Millisecond timestamp
This field is **optional.
end_date: Option<i64>Millisecond timestamp
This field is **optional.
page_index: Option<i64>Page number, empty default first page, starting from 1
This field is **optional.
page_size: Option<i64>Min 10,Max 200
This field is **optional.
recv_window: Option<i64>The recv_window parameter.
This field is **optional.
Implementations
Sourceimpl MiningAccountEarningParams
impl MiningAccountEarningParams
Sourcepub fn builder(algo: String) -> MiningAccountEarningParamsBuilder
pub fn builder(algo: String) -> MiningAccountEarningParamsBuilder
Create a builder for [mining_account_earning].
Required parameters:
algo— Algorithm(sha256) sha256