RequestForMinerListParams

Struct RequestForMinerListParams 

pub struct RequestForMinerListParams {
    pub algo: String,
    pub user_name: String,
    pub page_index: Option<i64>,
    pub sort: Option<i64>,
    pub sort_column: Option<i64>,
    pub worker_status: Option<i64>,
    pub recv_window: Option<i64>,
}
Request parameters for the [request_for_miner_list] operation.

This struct holds all of the inputs you can pass when calling request_for_miner_list.

Fields

algo: String

Algorithm(sha256) sha256

This field is **required.

user_name: String

Mining account test

This field is **required.

page_index: Option<i64>

Page number, empty default first page, starting from 1

This field is **optional.

sort: Option<i64>

sort sequence(default=0)0 positive sequence,1 negative sequence

This field is **optional.

sort_column: Option<i64>

Sort by( default 1):

1: miner name,

2: real-time computing power,

3: daily average computing power,

4: real-time rejection rate,

5: last submission time

This field is **optional.

worker_status: Option<i64>

miners status(default=0),0 all,1 valid,2 invalid,3 failure

This field is **optional.

recv_window: Option<i64>

The recv_window parameter.

This field is **optional.

Implementations

Source

impl RequestForMinerListParams

pub fn builder( algo: String, user_name: String, ) -> RequestForMinerListParamsBuilder

Create a builder for [request_for_miner_list].

Required parameters:

  • algo — Algorithm(sha256) sha256
  • user_name — Mining account test