pub struct ExtraBonusListParams {
pub algo: String,
pub user_name: String,
pub coin: Option<String>,
pub start_date: Option<i64>,
pub end_date: Option<i64>,
pub page_index: Option<i64>,
pub page_size: Option<i64>,
pub recv_window: Option<i64>,
}Expand description
Request parameters for the [extra_bonus_list] operation.
This struct holds all of the inputs you can pass when calling
extra_bonus_list.
Fields
algo: StringAlgorithm(sha256) sha256
This field is **required.
user_name: StringMining account test
This field is **required.
coin: Option<String>Coin Name
This field is **optional.
start_date: Option<i64>Millisecond timestamp
This field is **optional.
end_date: Option<i64>Millisecond timestamp
This field is **optional.
page_index: Option<i64>Page number, empty default first page, starting from 1
This field is **optional.
page_size: Option<i64>Min 10,Max 200
This field is **optional.
recv_window: Option<i64>The recv_window parameter.
This field is **optional.
Implementations
Sourceimpl ExtraBonusListParams
impl ExtraBonusListParams
Sourcepub fn builder(algo: String, user_name: String) -> ExtraBonusListParamsBuilder
pub fn builder(algo: String, user_name: String) -> ExtraBonusListParamsBuilder
Create a builder for [extra_bonus_list].
Required parameters:
algo— Algorithm(sha256) sha256user_name— Mining account test