pub struct RestApi { /* private fields */ }Implementations
Sourceimpl RestApi
impl RestApi
pub fn new(configuration: ConfigurationRestApi) -> Self
Sourcepub async fn send_request<R: DeserializeOwned + Send + 'static>(
&self,
endpoint: &str,
method: Method,
query_params: BTreeMap<String, Value>,
body_params: BTreeMap<String, Value>,
) -> Result<RestApiResponse<R>>
pub async fn send_request<R: DeserializeOwned + Send + 'static>( &self, endpoint: &str, method: Method, query_params: BTreeMap<String, Value>, body_params: BTreeMap<String, Value>, ) -> Result<RestApiResponse<R>>
Send an unsigned request to the API
Arguments
endpoint- The API endpoint to send the request tomethod- The HTTP method to use for the requestquery_params- A map of query parameters to send with the requestbody_params- A map of body parameters to send with the request
Returns
A RestApiResponse containing the deserialized response data on success, or an error if the request fails
Errors
Returns an anyhow::Error if the HTTP request fails or if parsing the response fails
Sourcepub async fn send_signed_request<R: DeserializeOwned + Send + 'static>(
&self,
endpoint: &str,
method: Method,
query_params: BTreeMap<String, Value>,
body_params: BTreeMap<String, Value>,
) -> Result<RestApiResponse<R>>
pub async fn send_signed_request<R: DeserializeOwned + Send + 'static>( &self, endpoint: &str, method: Method, query_params: BTreeMap<String, Value>, body_params: BTreeMap<String, Value>, ) -> Result<RestApiResponse<R>>
Send a signed request to the API
Arguments
endpoint- The API endpoint to send the request tomethod- The HTTP method to use for the requestquery_params- A map of query parameters to send with the requestbody_params- A map of body parameters to send with the request
Returns
A RestApiResponse containing the deserialized response data on success, or an error if the request fails
Errors
Returns an anyhow::Error if the HTTP request fails or if parsing the response fails
Sourcepub async fn get_pay_trade_history(
&self,
params: GetPayTradeHistoryParams,
) -> Result<RestApiResponse<GetPayTradeHistoryResponse>>
pub async fn get_pay_trade_history( &self, params: GetPayTradeHistoryParams, ) -> Result<RestApiResponse<GetPayTradeHistoryResponse>>
Get Pay Trade History
Get Pay Trade History
- If startTime and endTime are not sent, the recent 90 days’ data will be returned.
- The max interval between startTime and endTime is 90 days.
- Support for querying orders within the last 18 months.
- For payerInfo and receiverInfo,there are different return values in different orderTypes.
- Sender’s perspective when orderType is C2C
- payerInfo : binanceId
- receiverInfo : name, binanceId/accountId/email/countryCode/phoneNumber/mobileCode (based on user input)
- Receiver’s perspective when orderType is C2C
- payerInfo : name
- receiverInfo : binanceId
- Sender’s perspective when orderType is
CRYPTO_BOX - payerInfo : binanceId
- receiverInfo : name(the value is always “Crypto Box”)
- Receiver’s perspective when orderType is
CRYPTO_BOX - payerInfo : name
- receiverInfo : binanceId
- Sender’s perspective when orderType is PAY
- payerInfo : binanceId
- receiverInfo : name
- Receiver’s perspective when orderType is PAY
- payerInfo : name
- receiverInfo : binanceId, name
- Sender’s perspective when orderType is
PAY_REFUND - payerInfo : binanceId, name
- receiverInfo : name, accountId
- Receiver’s perspective when orderType is
PAY_REFUND - payerInfo : name
- receiverInfo : binanceId
- Sender’s perspective when orderType is PAYOUT
- payerInfo : binanceId, name
- receiverInfo : name, accountId
- Receiver’s perspective when orderType is PAYOUT
- payerInfo : name
- receiverInfo : binanceId
- Receiver’s perspective when orderType is
CRYPTO_BOX_RF - payerInfo : name(the value is always “Crypto Box”)
- receiverInfo : binanceId
- Sender’s perspective when orderType is REMITTANCE
- payerInfo : binanceId
- receiverInfo : name, institutionName, cardNumber, digitalWalletId
Weight: 3000
Arguments
params:GetPayTradeHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetPayTradeHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.