pub struct DeleteOrderResponse {Show 31 fields
pub symbol: Option<String>,
pub order_id: Option<i64>,
pub order_list_id: Option<i64>,
pub orig_client_order_id: Option<String>,
pub client_order_id: Option<String>,
pub transact_time: Option<i64>,
pub price: Option<String>,
pub orig_qty: Option<String>,
pub executed_qty: Option<String>,
pub orig_quote_order_qty: Option<String>,
pub cummulative_quote_qty: Option<String>,
pub status: Option<String>,
pub time_in_force: Option<String>,
pub type: Option<String>,
pub side: Option<String>,
pub self_trade_prevention_mode: Option<String>,
pub iceberg_qty: Option<String>,
pub prevented_match_id: Option<i64>,
pub prevented_quantity: Option<String>,
pub stop_price: Option<String>,
pub strategy_id: Option<i64>,
pub strategy_type: Option<i64>,
pub trailing_delta: Option<i64>,
pub trailing_time: Option<i64>,
pub used_sor: Option<bool>,
pub working_floor: Option<String>,
pub peg_price_type: Option<String>,
pub peg_offset_type: Option<String>,
pub peg_offset_value: Option<i64>,
pub pegged_price: Option<String>,
pub expiry_reason: Option<String>,
}Fields
symbol: Option<String>order_id: Option<i64>order_list_id: Option<i64>Unless it’s part of an order list, value will be -1
orig_client_order_id: Option<String>client_order_id: Option<String>transact_time: Option<i64>price: Option<String>orig_qty: Option<String>executed_qty: Option<String>orig_quote_order_qty: Option<String>cummulative_quote_qty: Option<String>status: Option<String>time_in_force: Option<String>type: Option<String>side: Option<String>self_trade_prevention_mode: Option<String>iceberg_qty: Option<String>Quantity for the iceberg order. Appears only if the parameter icebergQty was sent in the request.
prevented_match_id: Option<i64>When used together with symbol, can be used to query a prevented match. Appears only if the order expired due to STP.
prevented_quantity: Option<String>Order quantity that expired due to STP. Appears only if the order expired due to STP.
stop_price: Option<String>Price when the algorithmic order will be triggered. Appears for STOP_LOSS, TAKE_PROFIT, STOP_LOSS_LIMIT, and TAKE_PROFIT_LIMIT orders.
strategy_id: Option<i64>Can be used to label an order that’s part of an order strategy. Appears if the parameter was populated in the request.
strategy_type: Option<i64>Can be used to label an order that is using an order strategy. Appears if the parameter was populated in the request.
trailing_delta: Option<i64>Delta price change required before order activation. Appears for trailing stop orders.
trailing_time: Option<i64>Time when the trailing order becomes active and starts tracking price changes. Appears only for trailing stop orders.
used_sor: Option<bool>Indicates whether the order used SOR. Appears when placing orders using SOR.
working_floor: Option<String>Indicates whether the order is being filled by SOR or by the order book to which it was submitted. Appears when placing orders using SOR.
peg_price_type: Option<String>Price peg type. Only for pegged orders.
peg_offset_type: Option<String>Price peg offset type. Only for pegged orders, if requested.
peg_offset_value: Option<i64>Price peg offset value. Only for pegged orders, if requested.
pegged_price: Option<String>Current price the order is pegged at. Only for pegged orders, once determined.
expiry_reason: Option<String>Cause of the order’s expiration. Returned when an order has expired.
Implementations
Sourceimpl DeleteOrderResponse
impl DeleteOrderResponse
pub fn new() -> DeleteOrderResponse