pub struct GetOpenOrdersResponseInner {Show 33 fields
pub symbol: Option<String>,
pub order_id: Option<i64>,
pub order_list_id: Option<i64>,
pub client_order_id: Option<String>,
pub price: Option<String>,
pub orig_qty: Option<String>,
pub executed_qty: Option<String>,
pub orig_quote_order_qty: Option<String>,
pub cummulative_quote_qty: Option<String>,
pub status: Option<String>,
pub time_in_force: Option<String>,
pub type: Option<String>,
pub side: Option<String>,
pub stop_price: Option<String>,
pub iceberg_qty: Option<String>,
pub time: Option<i64>,
pub update_time: Option<i64>,
pub is_working: Option<bool>,
pub working_time: Option<i64>,
pub self_trade_prevention_mode: Option<String>,
pub prevented_match_id: Option<i64>,
pub prevented_quantity: Option<String>,
pub strategy_id: Option<i64>,
pub strategy_type: Option<i64>,
pub trailing_delta: Option<i64>,
pub trailing_time: Option<i64>,
pub used_sor: Option<bool>,
pub working_floor: Option<String>,
pub peg_price_type: Option<String>,
pub peg_offset_type: Option<String>,
pub peg_offset_value: Option<i64>,
pub pegged_price: Option<String>,
pub expiry_reason: Option<String>,
}Fields
symbol: Option<String>order_id: Option<i64>order_list_id: Option<i64>Unless it’s part of an order list, value will be -1
client_order_id: Option<String>price: Option<String>orig_qty: Option<String>executed_qty: Option<String>orig_quote_order_qty: Option<String>cummulative_quote_qty: Option<String>status: Option<String>time_in_force: Option<String>type: Option<String>side: Option<String>stop_price: Option<String>Appears for STOP_LOSS, TAKE_PROFIT, STOP_LOSS_LIMIT, and TAKE_PROFIT_LIMIT orders.
iceberg_qty: Option<String>Appears only if the parameter icebergQty was sent in the request.
time: Option<i64>update_time: Option<i64>is_working: Option<bool>working_time: Option<i64>self_trade_prevention_mode: Option<String>prevented_match_id: Option<i64>Appears only if the order expired due to STP.
prevented_quantity: Option<String>Order quantity that expired due to STP.
strategy_id: Option<i64>Appears only if the strategyId parameter was provided upon order placement.
strategy_type: Option<i64>Appears only if the strategyType parameter was provided upon order placement.
trailing_delta: Option<i64>Delta price change required before order activation.
trailing_time: Option<i64>Time when the trailing order is now active and tracking price changes.
used_sor: Option<bool>Field that determines whether order used SOR.
working_floor: Option<String>Determines whether the order is being filled by the SOR or by the order book.
peg_price_type: Option<String>Price peg type. Only for pegged orders.
peg_offset_type: Option<String>Price peg offset type. Only for pegged orders, if requested.
peg_offset_value: Option<i64>Price peg offset value. Only for pegged orders, if requested.
pegged_price: Option<String>Current price order is pegged at. Only for pegged orders, once determined.
expiry_reason: Option<String>Cause of the order’s expiration. Appears when an order has expired.
Implementations
Sourceimpl GetOpenOrdersResponseInner
impl GetOpenOrdersResponseInner
pub fn new() -> GetOpenOrdersResponseInner