pub struct GetOrderListParams {
pub order_list_id: Option<i64>,
pub orig_client_order_id: Option<String>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [get_order_list] operation.
This struct holds all of the inputs you can pass when calling
get_order_list.
Fields
order_list_id: Option<i64>Either orderListId or listClientOrderId must be provided
This field is **optional.
orig_client_order_id: Option<String>The orig_client_order_id parameter.
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl GetOrderListParams
impl GetOrderListParams
Sourcepub fn builder() -> GetOrderListParamsBuilder
pub fn builder() -> GetOrderListParamsBuilder
Create a builder for [get_order_list].