pub struct OpenOrderListParams {
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [open_order_list] operation.
This struct holds all of the inputs you can pass when calling
open_order_list.
Fields
recv_window: Option<Decimal>Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OpenOrderListParams
impl OpenOrderListParams
Sourcepub fn builder() -> OpenOrderListParamsBuilder
pub fn builder() -> OpenOrderListParamsBuilder
Create a builder for [open_order_list].