OrderOcoParams

Struct OrderOcoParams 

pub struct OrderOcoParams {
Show 20 fields pub symbol: String, pub side: OrderOcoSideEnum, pub quantity: Decimal, pub price: Decimal, pub stop_price: Decimal, pub list_client_order_id: Option<String>, pub limit_client_order_id: Option<String>, pub limit_strategy_id: Option<i64>, pub limit_strategy_type: Option<i32>, pub limit_iceberg_qty: Option<Decimal>, pub trailing_delta: Option<i64>, pub stop_client_order_id: Option<String>, pub stop_strategy_id: Option<i64>, pub stop_strategy_type: Option<i32>, pub stop_limit_price: Option<Decimal>, pub stop_iceberg_qty: Option<Decimal>, pub stop_limit_time_in_force: Option<OrderOcoStopLimitTimeInForceEnum>, pub new_order_resp_type: Option<OrderOcoNewOrderRespTypeEnum>, pub self_trade_prevention_mode: Option<OrderOcoSelfTradePreventionModeEnum>, pub recv_window: Option<Decimal>,
}
Request parameters for the [order_oco] operation.

This struct holds all of the inputs you can pass when calling order_oco.

Fields

symbol: String

The symbol parameter.

This field is **required.

side: OrderOcoSideEnum

The side parameter.

This field is **required.

quantity: Decimal

The quantity parameter.

This field is **required.

price: Decimal

The price parameter.

This field is **required.

stop_price: Decimal

The stop_price parameter.

This field is **required.

list_client_order_id: Option<String>

A unique Id for the entire orderList

This field is **optional.

limit_client_order_id: Option<String>

A unique Id for the limit order

This field is **optional.

limit_strategy_id: Option<i64>

The limit_strategy_id parameter.

This field is **optional.

limit_strategy_type: Option<i32>

The value cannot be less than 1000000.

This field is **optional.

limit_iceberg_qty: Option<Decimal>

Used to make the LIMIT_MAKER leg an iceberg order.

This field is **optional.

trailing_delta: Option<i64>

See Trailing Stop order FAQ.

This field is **optional.

stop_client_order_id: Option<String>

A unique Id for the stop loss/stop loss limit leg

This field is **optional.

stop_strategy_id: Option<i64>

The stop_strategy_id parameter.

This field is **optional.

stop_strategy_type: Option<i32>

The value cannot be less than 1000000.

This field is **optional.

stop_limit_price: Option<Decimal>

If provided, stopLimitTimeInForce is required.

This field is **optional.

stop_iceberg_qty: Option<Decimal>

Used with STOP_LOSS_LIMIT leg to make an iceberg order.

This field is **optional.

stop_limit_time_in_force: Option<OrderOcoStopLimitTimeInForceEnum>

The stop_limit_time_in_force parameter.

This field is **optional.

new_order_resp_type: Option<OrderOcoNewOrderRespTypeEnum>

The new_order_resp_type parameter.

This field is **optional.

self_trade_prevention_mode: Option<OrderOcoSelfTradePreventionModeEnum>

The self_trade_prevention_mode parameter.

This field is **optional.

recv_window: Option<Decimal>

The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.

This field is **optional.

Implementations

Source

impl OrderOcoParams

pub fn builder( symbol: String, side: OrderOcoSideEnum, quantity: Decimal, price: Decimal, stop_price: Decimal, ) -> OrderOcoParamsBuilder

Create a builder for [order_oco].

Required parameters:

  • symbol — String
  • side — String
  • quantityrust_decimal::Decimal
  • pricerust_decimal::Decimal
  • stop_pricerust_decimal::Decimal