OrderTestParamsBuilder

Struct OrderTestParamsBuilder 

pub struct OrderTestParamsBuilder { /* private fields */ }
Builder for OrderTestParams.

Implementations

Source

impl OrderTestParamsBuilder

pub fn symbol<VALUE: Into<String>>(self, value: VALUE) -> Self

The symbol parameter.

This field is **required.

pub fn side<VALUE: Into<OrderTestSideEnum>>(self, value: VALUE) -> Self

The side parameter.

This field is **required.

pub fn type<VALUE: Into<OrderTestTypeEnum>>(self, value: VALUE) -> Self

The r#type parameter.

This field is **required.

pub fn compute_commission_rates<VALUE: Into<Option<bool>>>( self, value: VALUE, ) -> Self

Default: false
See Commissions FAQ to learn more.

This field is **optional.

pub fn time_in_force<VALUE: Into<Option<OrderTestTimeInForceEnum>>>( self, value: VALUE, ) -> Self

The time_in_force parameter.

This field is **optional.

pub fn quantity<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self

The quantity parameter.

This field is **optional.

pub fn quote_order_qty<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self

The quote_order_qty parameter.

This field is **optional.

pub fn price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self

The price parameter.

This field is **optional.

pub fn new_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

A unique id among open orders. Automatically generated if not sent.
Orders with the same newClientOrderID can be accepted only when the previous one is filled, otherwise the order will be rejected.

This field is **optional.

pub fn strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self

The strategy_id parameter.

This field is **optional.

pub fn strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self

The value cannot be less than 1000000.

This field is **optional.

pub fn stop_price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self

Used with STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, and TAKE_PROFIT_LIMIT orders.

This field is **optional.

pub fn trailing_delta<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self

See Trailing Stop order FAQ.

This field is **optional.

pub fn iceberg_qty<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self

Used with LIMIT, STOP_LOSS_LIMIT, and TAKE_PROFIT_LIMIT to create an iceberg order.

This field is **optional.

pub fn new_order_resp_type<VALUE: Into<Option<OrderTestNewOrderRespTypeEnum>>>( self, value: VALUE, ) -> Self

The new_order_resp_type parameter.

This field is **optional.

pub fn self_trade_prevention_mode<VALUE: Into<Option<OrderTestSelfTradePreventionModeEnum>>>( self, value: VALUE, ) -> Self

The self_trade_prevention_mode parameter.

This field is **optional.

pub fn peg_price_type<VALUE: Into<Option<OrderTestPegPriceTypeEnum>>>( self, value: VALUE, ) -> Self

The peg_price_type parameter.

This field is **optional.

pub fn peg_offset_value<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self

Priceleveltopegthepriceto(max:100).
SeePeggedOrdersInfo

This field is **optional.

pub fn peg_offset_type<VALUE: Into<Option<OrderTestPegOffsetTypeEnum>>>( self, value: VALUE, ) -> Self

The peg_offset_type parameter.

This field is **optional.

pub fn recv_window<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self

The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.

This field is **optional.

pub fn build(self) -> Result<OrderTestParams, ParamBuildError>

Builds a new OrderTestParams.

Errors

If a required field has not been initialized.