pub struct RateLimitOrderParams {
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [rate_limit_order] operation.
This struct holds all of the inputs you can pass when calling
rate_limit_order.
Fields
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl RateLimitOrderParams
impl RateLimitOrderParams
Sourcepub fn builder() -> RateLimitOrderParamsBuilder
pub fn builder() -> RateLimitOrderParamsBuilder
Create a builder for [rate_limit_order].