SorOrderTestParams

Struct SorOrderTestParams 

pub struct SorOrderTestParams {
Show 14 fields pub symbol: String, pub side: SorOrderTestSideEnum, pub type: SorOrderTestTypeEnum, pub quantity: Decimal, pub compute_commission_rates: Option<bool>, pub time_in_force: Option<SorOrderTestTimeInForceEnum>, pub price: Option<Decimal>, pub new_client_order_id: Option<String>, pub strategy_id: Option<i64>, pub strategy_type: Option<i32>, pub iceberg_qty: Option<Decimal>, pub new_order_resp_type: Option<SorOrderTestNewOrderRespTypeEnum>, pub self_trade_prevention_mode: Option<SorOrderTestSelfTradePreventionModeEnum>, pub recv_window: Option<Decimal>,
}
Request parameters for the [sor_order_test] operation.

This struct holds all of the inputs you can pass when calling sor_order_test.

Fields

symbol: String

The symbol parameter.

This field is **required.

side: SorOrderTestSideEnum

The side parameter.

This field is **required.

type: SorOrderTestTypeEnum

The r#type parameter.

This field is **required.

quantity: Decimal

The quantity parameter.

This field is **required.

compute_commission_rates: Option<bool>

Default: false
See Commissions FAQ to learn more.

This field is **optional.

time_in_force: Option<SorOrderTestTimeInForceEnum>

The time_in_force parameter.

This field is **optional.

price: Option<Decimal>

The price parameter.

This field is **optional.

new_client_order_id: Option<String>

A unique id among open orders. Automatically generated if not sent.
Orders with the same newClientOrderID can be accepted only when the previous one is filled, otherwise the order will be rejected.

This field is **optional.

strategy_id: Option<i64>

The strategy_id parameter.

This field is **optional.

strategy_type: Option<i32>

The value cannot be less than 1000000.

This field is **optional.

iceberg_qty: Option<Decimal>

Used with LIMIT, STOP_LOSS_LIMIT, and TAKE_PROFIT_LIMIT to create an iceberg order.

This field is **optional.

new_order_resp_type: Option<SorOrderTestNewOrderRespTypeEnum>

The new_order_resp_type parameter.

This field is **optional.

self_trade_prevention_mode: Option<SorOrderTestSelfTradePreventionModeEnum>

The self_trade_prevention_mode parameter.

This field is **optional.

recv_window: Option<Decimal>

The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.

This field is **optional.

Implementations

Source

impl SorOrderTestParams

pub fn builder( symbol: String, side: SorOrderTestSideEnum, type: SorOrderTestTypeEnum, quantity: Decimal, ) -> SorOrderTestParamsBuilder

Create a builder for [sor_order_test].

Required parameters:

  • symbol — String
  • side — String
  • r#type — String
  • quantityrust_decimal::Decimal