pub struct TickerParams {
pub symbol: Option<String>,
pub symbols: Option<Vec<String>>,
pub window_size: Option<TickerWindowSizeEnum>,
pub type: Option<TickerTypeEnum>,
pub symbol_status: Option<TickerSymbolStatusEnum>,
}Expand description
Request parameters for the [ticker] operation.
This struct holds all of the inputs you can pass when calling
ticker.
Fields
symbol: Option<String>Either symbol or symbols must be provided
This field is **optional.
symbols: Option<Vec<String>>Either symbol or symbols must be provided
Examples of accepted format for the symbols parameter: [“BTCUSDT”,“BNBUSDT”] or %5B%22BTCUSDT%22,%22BNBUSDT%22%5D
The maximum number of symbols allowed in a request is 100.
This field is **optional.
window_size: Option<TickerWindowSizeEnum>Units cannot be combined (e.g. 1d2h is not allowed).
This field is **optional.
type: Option<TickerTypeEnum>The r#type parameter.
This field is **optional.
symbol_status: Option<TickerSymbolStatusEnum>The symbol_status parameter.
This field is **optional.
Implementations
Sourceimpl TickerParams
impl TickerParams
Sourcepub fn builder() -> TickerParamsBuilder
pub fn builder() -> TickerParamsBuilder
Create a builder for [ticker].