pub struct SpotWsStreams {}Expand description
Represents the Spot WebSocket Streams client for interacting with the Binance Spot WebSocket Streams.
This struct provides methods to create WebSocket Streams clients for production , demo and testnet environments.
Implementations
Sourceimpl SpotWsStreams
impl SpotWsStreams
Sourcepub fn from_config(
config: ConfigurationWebsocketStreams,
) -> WebsocketStreamsHandle
pub fn from_config( config: ConfigurationWebsocketStreams, ) -> WebsocketStreamsHandle
Creates a WebSocket streams client configured with the given settings.
If no WS URL is specified in the configuration, defaults to the production Spot WebSocket Streams URL.
Arguments
config- Configuration for the WebSocket streams client
Returns
A new WebSocket streams client configured with the provided settings
Sourcepub fn production(
config: ConfigurationWebsocketStreams,
) -> WebsocketStreamsHandle
pub fn production( config: ConfigurationWebsocketStreams, ) -> WebsocketStreamsHandle
Sourcepub fn testnet(config: ConfigurationWebsocketStreams) -> WebsocketStreamsHandle
pub fn testnet(config: ConfigurationWebsocketStreams) -> WebsocketStreamsHandle
Sourcepub fn demo(config: ConfigurationWebsocketStreams) -> WebsocketStreamsHandle
pub fn demo(config: ConfigurationWebsocketStreams) -> WebsocketStreamsHandle