pub struct SessionLogonParams {
pub id: Option<String>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [session_logon] operation.
This struct holds all of the inputs you can pass when calling
session_logon.
Fields
id: Option<String>Unique WebSocket request ID.
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl SessionLogonParams
impl SessionLogonParams
Sourcepub fn builder() -> SessionLogonParamsBuilder
pub fn builder() -> SessionLogonParamsBuilder
Create a builder for [session_logon].