pub struct AccountStatusParams {
pub id: Option<String>,
pub omit_zero_balances: Option<bool>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [account_status] operation.
This struct holds all of the inputs you can pass when calling
account_status.
Fields
id: Option<String>Unique WebSocket request ID.
This field is **optional.
omit_zero_balances: Option<bool>When set to true, emits only the non-zero balances of an account.
Default value: false
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl AccountStatusParams
impl AccountStatusParams
Sourcepub fn builder() -> AccountStatusParamsBuilder
pub fn builder() -> AccountStatusParamsBuilder
Create a builder for [account_status].