pub struct AllOrderListsParams {
pub id: Option<String>,
pub from_id: Option<i32>,
pub start_time: Option<i64>,
pub end_time: Option<i64>,
pub limit: Option<i32>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [all_order_lists] operation.
This struct holds all of the inputs you can pass when calling
all_order_lists.
Fields
id: Option<String>Unique WebSocket request ID.
This field is **optional.
from_id: Option<i32>Trade ID to begin at
This field is **optional.
start_time: Option<i64>The start_time parameter.
This field is **optional.
end_time: Option<i64>The end_time parameter.
This field is **optional.
limit: Option<i32>Default: 100; Maximum: 5000
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl AllOrderListsParams
impl AllOrderListsParams
Sourcepub fn builder() -> AllOrderListsParamsBuilder
pub fn builder() -> AllOrderListsParamsBuilder
Create a builder for [all_order_lists].