pub struct ExchangeInfoParams {
pub id: Option<String>,
pub symbol: Option<String>,
pub symbols: Option<Vec<String>>,
pub permissions: Option<Vec<String>>,
pub show_permission_sets: Option<bool>,
pub symbol_status: Option<ExchangeInfoSymbolStatusEnum>,
}Expand description
Request parameters for the [exchange_info] operation.
This struct holds all of the inputs you can pass when calling
exchange_info.
Fields
id: Option<String>Client-generated request identifier.
This field is **optional.
symbol: Option<String>Describe a single symbol
This field is **optional.
symbols: Option<Vec<String>>Describe multiple symbols
This field is **optional.
permissions: Option<Vec<String>>Filter symbols by permissions
This field is **optional.
show_permission_sets: Option<bool>Controls whether the content of the permissionSets field is populated or not. Defaults to true.
This field is **optional.
symbol_status: Option<ExchangeInfoSymbolStatusEnum>Filters for symbols that have this tradingStatus. Valid values: TRADING, HALT, BREAK. Cannot be used in combination with symbol or symbols.
This field is **optional.
Implementations
Sourceimpl ExchangeInfoParams
impl ExchangeInfoParams
Sourcepub fn builder() -> ExchangeInfoParamsBuilder
pub fn builder() -> ExchangeInfoParamsBuilder
Create a builder for [exchange_info].