pub struct MyAllocationsParams {
pub symbol: String,
pub id: Option<String>,
pub start_time: Option<i64>,
pub end_time: Option<i64>,
pub from_allocation_id: Option<i32>,
pub limit: Option<i32>,
pub order_id: Option<i64>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [my_allocations] operation.
This struct holds all of the inputs you can pass when calling
my_allocations.
Fields
symbol: StringThe symbol parameter.
This field is **required.
id: Option<String>Unique WebSocket request ID.
This field is **optional.
start_time: Option<i64>The start_time parameter.
This field is **optional.
end_time: Option<i64>The end_time parameter.
This field is **optional.
from_allocation_id: Option<i32>The from_allocation_id parameter.
This field is **optional.
limit: Option<i32>Default: 100; Maximum: 5000
This field is **optional.
order_id: Option<i64>orderIdororigClientOrderIdmustbesent
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl MyAllocationsParams
impl MyAllocationsParams
Sourcepub fn builder(symbol: String) -> MyAllocationsParamsBuilder
pub fn builder(symbol: String) -> MyAllocationsParamsBuilder
Create a builder for [my_allocations].
Required parameters:
symbol— String