pub struct OpenOrderListsStatusParams {
pub id: Option<String>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [open_order_lists_status] operation.
This struct holds all of the inputs you can pass when calling
open_order_lists_status.
Fields
id: Option<String>Unique WebSocket request ID.
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OpenOrderListsStatusParams
impl OpenOrderListsStatusParams
Sourcepub fn builder() -> OpenOrderListsStatusParamsBuilder
pub fn builder() -> OpenOrderListsStatusParamsBuilder
Create a builder for [open_order_lists_status].