pub struct OrderAmendKeepPriorityParams {
pub symbol: String,
pub new_qty: Decimal,
pub id: Option<String>,
pub order_id: Option<i64>,
pub orig_client_order_id: Option<String>,
pub new_client_order_id: Option<String>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [order_amend_keep_priority] operation.
This struct holds all of the inputs you can pass when calling
order_amend_keep_priority.
Fields
symbol: StringThe symbol parameter.
This field is **required.
new_qty: DecimalnewQty must be greater than 0 and less than the order’s quantity.
This field is **required.
id: Option<String>Unique WebSocket request ID.
This field is **optional.
order_id: Option<i64>orderIdororigClientOrderIdmustbesent
This field is **optional.
orig_client_order_id: Option<String>orderIdororigClientOrderIdmustbesent
This field is **optional.
new_client_order_id: Option<String>The new client order ID for the order after being amended.
If not sent, one will be randomly generated.
It is possible to reuse the current clientOrderId by sending it as the newClientOrderId.
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OrderAmendKeepPriorityParams
impl OrderAmendKeepPriorityParams
Sourcepub fn builder(
symbol: String,
new_qty: Decimal,
) -> OrderAmendKeepPriorityParamsBuilder
pub fn builder( symbol: String, new_qty: Decimal, ) -> OrderAmendKeepPriorityParamsBuilder
Create a builder for [order_amend_keep_priority].
Required parameters:
symbol— Stringnew_qty—newQtymust be greater than 0 and less than the order’s quantity.