pub struct OrderAmendmentsParams {
pub symbol: String,
pub order_id: i64,
pub id: Option<String>,
pub from_execution_id: Option<i64>,
pub limit: Option<i64>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [order_amendments] operation.
This struct holds all of the inputs you can pass when calling
order_amendments.
Fields
symbol: StringThe symbol parameter.
This field is **required.
order_id: i64The order_id parameter.
This field is **required.
id: Option<String>Unique WebSocket request ID.
This field is **optional.
from_execution_id: Option<i64>The from_execution_id parameter.
This field is **optional.
limit: Option<i64>Default: 500; Maximum: 1000
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OrderAmendmentsParams
impl OrderAmendmentsParams
Sourcepub fn builder(symbol: String, order_id: i64) -> OrderAmendmentsParamsBuilder
pub fn builder(symbol: String, order_id: i64) -> OrderAmendmentsParamsBuilder
Create a builder for [order_amendments].
Required parameters:
symbol— Stringorder_id— i64