pub struct OrderListPlaceOtocoParams {Show 44 fields
pub symbol: String,
pub working_type: OrderListPlaceOtocoWorkingTypeEnum,
pub working_side: OrderListPlaceOtocoWorkingSideEnum,
pub working_price: Decimal,
pub working_quantity: Decimal,
pub pending_side: OrderListPlaceOtocoPendingSideEnum,
pub pending_quantity: Decimal,
pub pending_above_type: OrderListPlaceOtocoPendingAboveTypeEnum,
pub id: Option<String>,
pub list_client_order_id: Option<String>,
pub new_order_resp_type: Option<OrderListPlaceOtocoNewOrderRespTypeEnum>,
pub self_trade_prevention_mode: Option<OrderListPlaceOtocoSelfTradePreventionModeEnum>,
pub working_client_order_id: Option<String>,
pub working_iceberg_qty: Option<Decimal>,
pub working_time_in_force: Option<OrderListPlaceOtocoWorkingTimeInForceEnum>,
pub working_strategy_id: Option<i64>,
pub working_strategy_type: Option<i32>,
pub working_peg_price_type: Option<OrderListPlaceOtocoWorkingPegPriceTypeEnum>,
pub working_peg_offset_type: Option<OrderListPlaceOtocoWorkingPegOffsetTypeEnum>,
pub working_peg_offset_value: Option<i32>,
pub pending_above_client_order_id: Option<String>,
pub pending_above_price: Option<Decimal>,
pub pending_above_stop_price: Option<Decimal>,
pub pending_above_trailing_delta: Option<Decimal>,
pub pending_above_iceberg_qty: Option<Decimal>,
pub pending_above_time_in_force: Option<OrderListPlaceOtocoPendingAboveTimeInForceEnum>,
pub pending_above_strategy_id: Option<i64>,
pub pending_above_strategy_type: Option<i32>,
pub pending_above_peg_price_type: Option<OrderListPlaceOtocoPendingAbovePegPriceTypeEnum>,
pub pending_above_peg_offset_type: Option<OrderListPlaceOtocoPendingAbovePegOffsetTypeEnum>,
pub pending_above_peg_offset_value: Option<i32>,
pub pending_below_type: Option<OrderListPlaceOtocoPendingBelowTypeEnum>,
pub pending_below_client_order_id: Option<String>,
pub pending_below_price: Option<Decimal>,
pub pending_below_stop_price: Option<Decimal>,
pub pending_below_trailing_delta: Option<Decimal>,
pub pending_below_iceberg_qty: Option<Decimal>,
pub pending_below_time_in_force: Option<OrderListPlaceOtocoPendingBelowTimeInForceEnum>,
pub pending_below_strategy_id: Option<i64>,
pub pending_below_strategy_type: Option<i32>,
pub pending_below_peg_price_type: Option<OrderListPlaceOtocoPendingBelowPegPriceTypeEnum>,
pub pending_below_peg_offset_type: Option<OrderListPlaceOtocoPendingBelowPegOffsetTypeEnum>,
pub pending_below_peg_offset_value: Option<i32>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [order_list_place_otoco] operation.
This struct holds all of the inputs you can pass when calling
order_list_place_otoco.
Fields
symbol: StringThe symbol parameter.
This field is **required.
working_type: OrderListPlaceOtocoWorkingTypeEnumThe working_type parameter.
This field is **required.
working_side: OrderListPlaceOtocoWorkingSideEnumThe working_side parameter.
This field is **required.
working_price: DecimalThe working_price parameter.
This field is **required.
working_quantity: DecimalSets the quantity for the working order.
This field is **required.
pending_side: OrderListPlaceOtocoPendingSideEnumThe pending_side parameter.
This field is **required.
pending_quantity: DecimalSets the quantity for the pending order.
This field is **required.
pending_above_type: OrderListPlaceOtocoPendingAboveTypeEnumThe pending_above_type parameter.
This field is **required.
id: Option<String>Unique WebSocket request ID.
This field is **optional.
list_client_order_id: Option<String>The list_client_order_id parameter.
This field is **optional.
new_order_resp_type: Option<OrderListPlaceOtocoNewOrderRespTypeEnum>The new_order_resp_type parameter.
This field is **optional.
self_trade_prevention_mode: Option<OrderListPlaceOtocoSelfTradePreventionModeEnum>The self_trade_prevention_mode parameter.
This field is **optional.
working_client_order_id: Option<String>Arbitrary unique ID among open orders for the working order. Automatically generated if not sent.
This field is **optional.
working_iceberg_qty: Option<Decimal>This can only be used if workingTimeInForce is GTC, or if workingType is LIMIT_MAKER.
This field is **optional.
working_time_in_force: Option<OrderListPlaceOtocoWorkingTimeInForceEnum>The working_time_in_force parameter.
This field is **optional.
working_strategy_id: Option<i64>Arbitrary numeric value identifying the working order within an order strategy.
This field is **optional.
working_strategy_type: Option<i32>Arbitrary numeric value identifying the working order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
working_peg_price_type: Option<OrderListPlaceOtocoWorkingPegPriceTypeEnum>The working_peg_price_type parameter.
This field is **optional.
working_peg_offset_type: Option<OrderListPlaceOtocoWorkingPegOffsetTypeEnum>The working_peg_offset_type parameter.
This field is **optional.
working_peg_offset_value: Option<i32>The working_peg_offset_value parameter.
This field is **optional.
pending_above_client_order_id: Option<String>Arbitrary unique ID among open orders for the pending above order. Automatically generated if not sent.
This field is **optional.
pending_above_price: Option<Decimal>Can be used if pendingAboveType is STOP_LOSS_LIMIT , LIMIT_MAKER, or TAKE_PROFIT_LIMIT to specify the limit price.
This field is **optional.
pending_above_stop_price: Option<Decimal>Can be used if pendingAboveType is STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, TAKE_PROFIT_LIMIT
This field is **optional.
pending_above_trailing_delta: Option<Decimal>This field is **optional.
pending_above_iceberg_qty: Option<Decimal>This can only be used if pendingAboveTimeInForce is GTC or if pendingAboveType is LIMIT_MAKER.
This field is **optional.
pending_above_time_in_force: Option<OrderListPlaceOtocoPendingAboveTimeInForceEnum>The pending_above_time_in_force parameter.
This field is **optional.
pending_above_strategy_id: Option<i64>Arbitrary numeric value identifying the pending above order within an order strategy.
This field is **optional.
pending_above_strategy_type: Option<i32>Arbitrary numeric value identifying the pending above order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
pending_above_peg_price_type: Option<OrderListPlaceOtocoPendingAbovePegPriceTypeEnum>The pending_above_peg_price_type parameter.
This field is **optional.
pending_above_peg_offset_type: Option<OrderListPlaceOtocoPendingAbovePegOffsetTypeEnum>The pending_above_peg_offset_type parameter.
This field is **optional.
pending_above_peg_offset_value: Option<i32>The pending_above_peg_offset_value parameter.
This field is **optional.
pending_below_type: Option<OrderListPlaceOtocoPendingBelowTypeEnum>The pending_below_type parameter.
This field is **optional.
pending_below_client_order_id: Option<String>Arbitrary unique ID among open orders for the pending below order. Automatically generated if not sent.
This field is **optional.
pending_below_price: Option<Decimal>Can be used if pendingBelowType is STOP_LOSS_LIMIT or TAKE_PROFIT_LIMIT to specify limit price
This field is **optional.
pending_below_stop_price: Option<Decimal>Can be used if pendingBelowType is STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT or TAKE_PROFIT_LIMIT. Either pendingBelowStopPrice or pendingBelowTrailingDelta or both, must be specified.
This field is **optional.
pending_below_trailing_delta: Option<Decimal>The pending_below_trailing_delta parameter.
This field is **optional.
pending_below_iceberg_qty: Option<Decimal>This can only be used if pendingBelowTimeInForce is GTC, or if pendingBelowType is LIMIT_MAKER.
This field is **optional.
pending_below_time_in_force: Option<OrderListPlaceOtocoPendingBelowTimeInForceEnum>The pending_below_time_in_force parameter.
This field is **optional.
pending_below_strategy_id: Option<i64>Arbitrary numeric value identifying the pending below order within an order strategy.
This field is **optional.
pending_below_strategy_type: Option<i32>Arbitrary numeric value identifying the pending below order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
pending_below_peg_price_type: Option<OrderListPlaceOtocoPendingBelowPegPriceTypeEnum>The pending_below_peg_price_type parameter.
This field is **optional.
pending_below_peg_offset_type: Option<OrderListPlaceOtocoPendingBelowPegOffsetTypeEnum>The pending_below_peg_offset_type parameter.
This field is **optional.
pending_below_peg_offset_value: Option<i32>The pending_below_peg_offset_value parameter.
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OrderListPlaceOtocoParams
impl OrderListPlaceOtocoParams
Sourcepub fn builder(
symbol: String,
working_type: OrderListPlaceOtocoWorkingTypeEnum,
working_side: OrderListPlaceOtocoWorkingSideEnum,
working_price: Decimal,
working_quantity: Decimal,
pending_side: OrderListPlaceOtocoPendingSideEnum,
pending_quantity: Decimal,
pending_above_type: OrderListPlaceOtocoPendingAboveTypeEnum,
) -> OrderListPlaceOtocoParamsBuilder
pub fn builder( symbol: String, working_type: OrderListPlaceOtocoWorkingTypeEnum, working_side: OrderListPlaceOtocoWorkingSideEnum, working_price: Decimal, working_quantity: Decimal, pending_side: OrderListPlaceOtocoPendingSideEnum, pending_quantity: Decimal, pending_above_type: OrderListPlaceOtocoPendingAboveTypeEnum, ) -> OrderListPlaceOtocoParamsBuilder
Create a builder for [order_list_place_otoco].
Required parameters:
symbol— Stringworking_type— Stringworking_side— Stringworking_price—rust_decimal::Decimalworking_quantity— Sets the quantity for the working order.pending_side— Stringpending_quantity— Sets the quantity for the pending order.pending_above_type— String