pub struct OrderListPlaceParams {Show 21 fields
pub symbol: String,
pub side: OrderListPlaceSideEnum,
pub price: Decimal,
pub quantity: Decimal,
pub id: Option<String>,
pub list_client_order_id: Option<String>,
pub limit_client_order_id: Option<String>,
pub limit_iceberg_qty: Option<Decimal>,
pub limit_strategy_id: Option<i64>,
pub limit_strategy_type: Option<i32>,
pub stop_price: Option<Decimal>,
pub trailing_delta: Option<i32>,
pub stop_client_order_id: Option<String>,
pub stop_limit_price: Option<Decimal>,
pub stop_limit_time_in_force: Option<OrderListPlaceStopLimitTimeInForceEnum>,
pub stop_iceberg_qty: Option<Decimal>,
pub stop_strategy_id: Option<i64>,
pub stop_strategy_type: Option<i32>,
pub new_order_resp_type: Option<OrderListPlaceNewOrderRespTypeEnum>,
pub self_trade_prevention_mode: Option<OrderListPlaceSelfTradePreventionModeEnum>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [order_list_place] operation.
This struct holds all of the inputs you can pass when calling
order_list_place.
Fields
symbol: StringThe symbol parameter.
This field is **required.
side: OrderListPlaceSideEnumPlease see Enums for supported values.
This field is **required.
price: DecimalThe price parameter.
This field is **required.
quantity: DecimalThe quantity parameter.
This field is **required.
id: Option<String>Client-generated request identifier.
This field is **optional.
list_client_order_id: Option<String>A unique Id for the entire orderList
This field is **optional.
limit_client_order_id: Option<String>A unique Id for the limit order
This field is **optional.
limit_iceberg_qty: Option<Decimal>Used to make the LIMIT_MAKER leg an iceberg order.
This field is **optional.
limit_strategy_id: Option<i64>The limit_strategy_id parameter.
This field is **optional.
limit_strategy_type: Option<i32>The value cannot be less than 1000000.
This field is **optional.
stop_price: Option<Decimal>The stop_price parameter.
This field is **optional.
trailing_delta: Option<i32>The trailing_delta parameter.
This field is **optional.
stop_client_order_id: Option<String>A unique Id for the stop loss/stop loss limit leg
This field is **optional.
stop_limit_price: Option<Decimal>If provided, stopLimitTimeInForce is required.
This field is **optional.
stop_limit_time_in_force: Option<OrderListPlaceStopLimitTimeInForceEnum>Valid values are GTC/FOK/IOC
This field is **optional.
stop_iceberg_qty: Option<Decimal>Used with STOP_LOSS_LIMIT leg to make an iceberg order.
This field is **optional.
stop_strategy_id: Option<i64>The stop_strategy_id parameter.
This field is **optional.
stop_strategy_type: Option<i32>The value cannot be less than 1000000.
This field is **optional.
new_order_resp_type: Option<OrderListPlaceNewOrderRespTypeEnum>Format of the JSON response. Supported values: Order Response Type
This field is **optional.
self_trade_prevention_mode: Option<OrderListPlaceSelfTradePreventionModeEnum>The allowed values are dependent on what is configured on the symbol. Supported values: STP Modes
This field is **optional.
recv_window: Option<Decimal>Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OrderListPlaceParams
impl OrderListPlaceParams
Sourcepub fn builder(
symbol: String,
side: OrderListPlaceSideEnum,
price: Decimal,
quantity: Decimal,
) -> OrderListPlaceParamsBuilder
pub fn builder( symbol: String, side: OrderListPlaceSideEnum, price: Decimal, quantity: Decimal, ) -> OrderListPlaceParamsBuilder
Create a builder for [order_list_place].
Required parameters:
symbol— Stringside— Please see Enums for supported values.price—rust_decimal::Decimalquantity—rust_decimal::Decimal