OrderListPlaceParamsBuilder

Struct OrderListPlaceParamsBuilder 

pub struct OrderListPlaceParamsBuilder { /* private fields */ }
Builder for OrderListPlaceParams.

Implementations

Source

impl OrderListPlaceParamsBuilder

pub fn symbol<VALUE: Into<String>>(self, value: VALUE) -> Self

The symbol parameter.

This field is **required.

pub fn side<VALUE: Into<OrderListPlaceSideEnum>>(self, value: VALUE) -> Self

The side parameter.

This field is **required.

pub fn price<VALUE: Into<Decimal>>(self, value: VALUE) -> Self

Price for the limit order

This field is **required.

pub fn quantity<VALUE: Into<Decimal>>(self, value: VALUE) -> Self

The quantity parameter.

This field is **required.

pub fn id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Unique WebSocket request ID.

This field is **optional.

pub fn list_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

The list_client_order_id parameter.

This field is **optional.

pub fn limit_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Arbitrary unique ID among open orders for the limit order. Automatically generated if not sent

This field is **optional.

pub fn limit_iceberg_qty<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self

The limit_iceberg_qty parameter.

This field is **optional.

pub fn limit_strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self

Arbitrary numeric value identifying the limit order within an order strategy.

This field is **optional.

pub fn limit_strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self

Arbitrary numeric value identifying the limit order strategy.

Values smaller than `1000000` are reserved and cannot be used.

This field is **optional.

pub fn stop_price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self

The stop_price parameter.

This field is **optional.

pub fn trailing_delta<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self

See Trailing Stop order FAQ

This field is **optional.

pub fn stop_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self

Arbitrary unique ID among open orders for the stop order. Automatically generated if not sent

This field is **optional.

pub fn stop_limit_price<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self

The stop_limit_price parameter.

This field is **optional.

pub fn stop_limit_time_in_force<VALUE: Into<Option<OrderListPlaceStopLimitTimeInForceEnum>>>( self, value: VALUE, ) -> Self

The stop_limit_time_in_force parameter.

This field is **optional.

pub fn stop_iceberg_qty<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self

The stop_iceberg_qty parameter.

This field is **optional.

pub fn stop_strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self

Arbitrary numeric value identifying the stop order within an order strategy.

This field is **optional.

pub fn stop_strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self

Arbitrary numeric value identifying the stop order strategy.

Values smaller than `1000000` are reserved and cannot be used.

This field is **optional.

pub fn new_order_resp_type<VALUE: Into<Option<OrderListPlaceNewOrderRespTypeEnum>>>( self, value: VALUE, ) -> Self

The new_order_resp_type parameter.

This field is **optional.

pub fn self_trade_prevention_mode<VALUE: Into<Option<OrderListPlaceSelfTradePreventionModeEnum>>>( self, value: VALUE, ) -> Self

The self_trade_prevention_mode parameter.

This field is **optional.

pub fn recv_window<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self

The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.

This field is **optional.

pub fn build(self) -> Result<OrderListPlaceParams, ParamBuildError>

Builds a new OrderListPlaceParams.

Errors

If a required field has not been initialized.