pub struct OrderListStatusParams {
pub id: Option<String>,
pub orig_client_order_id: Option<String>,
pub order_list_id: Option<i32>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [order_list_status] operation.
This struct holds all of the inputs you can pass when calling
order_list_status.
Fields
id: Option<String>Unique WebSocket request ID.
This field is **optional.
orig_client_order_id: Option<String>orderIdororigClientOrderIdmustbesent
This field is **optional.
order_list_id: Option<i32>Cancel order list by orderListId
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OrderListStatusParams
impl OrderListStatusParams
Sourcepub fn builder() -> OrderListStatusParamsBuilder
pub fn builder() -> OrderListStatusParamsBuilder
Create a builder for [order_list_status].