OrderTestParams

Struct OrderTestParams 

pub struct OrderTestParams {
Show 21 fields pub symbol: String, pub side: OrderTestSideEnum, pub type: OrderTestTypeEnum, pub id: Option<String>, pub compute_commission_rates: Option<bool>, pub time_in_force: Option<OrderTestTimeInForceEnum>, pub price: Option<Decimal>, pub quantity: Option<Decimal>, pub quote_order_qty: Option<Decimal>, pub new_client_order_id: Option<String>, pub new_order_resp_type: Option<OrderTestNewOrderRespTypeEnum>, pub stop_price: Option<Decimal>, pub trailing_delta: Option<i32>, pub iceberg_qty: Option<Decimal>, pub strategy_id: Option<i64>, pub strategy_type: Option<i32>, pub self_trade_prevention_mode: Option<OrderTestSelfTradePreventionModeEnum>, pub peg_price_type: Option<OrderTestPegPriceTypeEnum>, pub peg_offset_value: Option<i32>, pub peg_offset_type: Option<OrderTestPegOffsetTypeEnum>, pub recv_window: Option<Decimal>,
}
Request parameters for the [order_test] operation.

This struct holds all of the inputs you can pass when calling order_test.

Fields

symbol: String

The symbol parameter.

This field is **required.

side: OrderTestSideEnum

The side parameter.

This field is **required.

type: OrderTestTypeEnum

The r#type parameter.

This field is **required.

id: Option<String>

Unique WebSocket request ID.

This field is **optional.

compute_commission_rates: Option<bool>

Default: false
See Commissions FAQ to learn more.

This field is **optional.

time_in_force: Option<OrderTestTimeInForceEnum>

The time_in_force parameter.

This field is **optional.

price: Option<Decimal>

The price parameter.

This field is **optional.

quantity: Option<Decimal>

The quantity parameter.

This field is **optional.

quote_order_qty: Option<Decimal>

The quote_order_qty parameter.

This field is **optional.

new_client_order_id: Option<String>

The new client order ID for the order after being amended.
If not sent, one will be randomly generated.
It is possible to reuse the current clientOrderId by sending it as the newClientOrderId.

This field is **optional.

new_order_resp_type: Option<OrderTestNewOrderRespTypeEnum>

The new_order_resp_type parameter.

This field is **optional.

stop_price: Option<Decimal>

The stop_price parameter.

This field is **optional.

trailing_delta: Option<i32>

See Trailing Stop order FAQ

This field is **optional.

iceberg_qty: Option<Decimal>

The iceberg_qty parameter.

This field is **optional.

strategy_id: Option<i64>

Arbitrary numeric value identifying the order within an order strategy.

This field is **optional.

strategy_type: Option<i32>

Arbitrary numeric value identifying the order strategy. Values smaller than 1000000 are reserved and cannot be used.

This field is **optional.

self_trade_prevention_mode: Option<OrderTestSelfTradePreventionModeEnum>

The self_trade_prevention_mode parameter.

This field is **optional.

peg_price_type: Option<OrderTestPegPriceTypeEnum>

The peg_price_type parameter.

This field is **optional.

peg_offset_value: Option<i32>

Price level to peg the price to (max: 100) See Pegged Orders

This field is **optional.

peg_offset_type: Option<OrderTestPegOffsetTypeEnum>

The peg_offset_type parameter.

This field is **optional.

recv_window: Option<Decimal>

The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.

This field is **optional.

Implementations

Source

impl OrderTestParams

pub fn builder( symbol: String, side: OrderTestSideEnum, type: OrderTestTypeEnum, ) -> OrderTestParamsBuilder

Create a builder for [order_test].

Required parameters:

  • symbol — String
  • side — String
  • r#type — String