pub struct ReferencePriceCalculationResponseResult {
pub symbol: Option<String>,
pub calculation_type: Option<String>,
pub bucket_count: Option<i64>,
pub bucket_width_ms: Option<i64>,
pub external_calculation_id: Option<i64>,
}Fields
symbol: Option<String>calculation_type: Option<String>bucket_count: Option<i64>If the reference price is being calculated by the matching engine as an arithmetic mean
bucket_width_ms: Option<i64>If the reference price is being calculated by the matching engine as an arithmetic mean
external_calculation_id: Option<i64>If the reference price is being calculated outside the matching engine
Implementations