SorOrderPlaceParams

Struct SorOrderPlaceParams 

pub struct SorOrderPlaceParams {
Show 14 fields pub symbol: String, pub side: SorOrderPlaceSideEnum, pub type: SorOrderPlaceTypeEnum, pub quantity: Decimal, pub id: Option<String>, pub time_in_force: Option<SorOrderPlaceTimeInForceEnum>, pub price: Option<Decimal>, pub new_client_order_id: Option<String>, pub new_order_resp_type: Option<SorOrderPlaceNewOrderRespTypeEnum>, pub iceberg_qty: Option<Decimal>, pub strategy_id: Option<i64>, pub strategy_type: Option<i32>, pub self_trade_prevention_mode: Option<SorOrderPlaceSelfTradePreventionModeEnum>, pub recv_window: Option<Decimal>,
}
Request parameters for the [sor_order_place] operation.

This struct holds all of the inputs you can pass when calling sor_order_place.

Fields

symbol: String

The symbol parameter.

This field is **required.

side: SorOrderPlaceSideEnum

The side parameter.

This field is **required.

type: SorOrderPlaceTypeEnum

The r#type parameter.

This field is **required.

quantity: Decimal

The quantity parameter.

This field is **required.

id: Option<String>

Unique WebSocket request ID.

This field is **optional.

time_in_force: Option<SorOrderPlaceTimeInForceEnum>

The time_in_force parameter.

This field is **optional.

price: Option<Decimal>

The price parameter.

This field is **optional.

new_client_order_id: Option<String>

The new client order ID for the order after being amended.
If not sent, one will be randomly generated.
It is possible to reuse the current clientOrderId by sending it as the newClientOrderId.

This field is **optional.

new_order_resp_type: Option<SorOrderPlaceNewOrderRespTypeEnum>

The new_order_resp_type parameter.

This field is **optional.

iceberg_qty: Option<Decimal>

The iceberg_qty parameter.

This field is **optional.

strategy_id: Option<i64>

Arbitrary numeric value identifying the order within an order strategy.

This field is **optional.

strategy_type: Option<i32>

Arbitrary numeric value identifying the order strategy. Values smaller than 1000000 are reserved and cannot be used.

This field is **optional.

self_trade_prevention_mode: Option<SorOrderPlaceSelfTradePreventionModeEnum>

The self_trade_prevention_mode parameter.

This field is **optional.

recv_window: Option<Decimal>

The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.

This field is **optional.

Implementations

Source

impl SorOrderPlaceParams

pub fn builder( symbol: String, side: SorOrderPlaceSideEnum, type: SorOrderPlaceTypeEnum, quantity: Decimal, ) -> SorOrderPlaceParamsBuilder

Create a builder for [sor_order_place].

Required parameters:

  • symbol — String
  • side — String
  • r#type — String
  • quantityrust_decimal::Decimal