pub struct SorOrderTestParams {Show 15 fields
pub symbol: String,
pub side: SorOrderTestSideEnum,
pub type: SorOrderTestTypeEnum,
pub quantity: Decimal,
pub id: Option<String>,
pub compute_commission_rates: Option<bool>,
pub time_in_force: Option<SorOrderTestTimeInForceEnum>,
pub price: Option<Decimal>,
pub new_client_order_id: Option<String>,
pub new_order_resp_type: Option<SorOrderTestNewOrderRespTypeEnum>,
pub iceberg_qty: Option<Decimal>,
pub strategy_id: Option<i64>,
pub strategy_type: Option<i32>,
pub self_trade_prevention_mode: Option<SorOrderTestSelfTradePreventionModeEnum>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [sor_order_test] operation.
This struct holds all of the inputs you can pass when calling
sor_order_test.
Fields
symbol: StringThe symbol parameter.
This field is **required.
side: SorOrderTestSideEnumPlease see Enums for supported values.
This field is **required.
type: SorOrderTestTypeEnumPlease see Enums for supported values.
This field is **required.
quantity: DecimalThe quantity parameter.
This field is **required.
id: Option<String>Client-generated request identifier.
This field is **optional.
compute_commission_rates: Option<bool>Default: false
This field is **optional.
time_in_force: Option<SorOrderTestTimeInForceEnum>Please see Enums for supported values.
This field is **optional.
price: Option<Decimal>The price parameter.
This field is **optional.
new_client_order_id: Option<String>A unique id among open orders. Automatically generated if not sent. Orders with the same newClientOrderID can be accepted only when the previous one is filled, otherwise the order will be rejected.
This field is **optional.
new_order_resp_type: Option<SorOrderTestNewOrderRespTypeEnum>Set the response JSON. ACK, RESULT, or FULL. Default to FULL.
This field is **optional.
iceberg_qty: Option<Decimal>Used with LIMIT to create an iceberg order.
This field is **optional.
strategy_id: Option<i64>The strategy_id parameter.
This field is **optional.
strategy_type: Option<i32>The value cannot be less than 1000000.
This field is **optional.
self_trade_prevention_mode: Option<SorOrderTestSelfTradePreventionModeEnum>The allowed enums is dependent on what is configured on the symbol. Supported values: STP Modes
This field is **optional.
recv_window: Option<Decimal>Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl SorOrderTestParams
impl SorOrderTestParams
Sourcepub fn builder(
symbol: String,
side: SorOrderTestSideEnum,
type: SorOrderTestTypeEnum,
quantity: Decimal,
) -> SorOrderTestParamsBuilder
pub fn builder( symbol: String, side: SorOrderTestSideEnum, type: SorOrderTestTypeEnum, quantity: Decimal, ) -> SorOrderTestParamsBuilder