pub struct Ticker24hrParams {
pub id: Option<String>,
pub symbol: Option<String>,
pub symbols: Option<Vec<String>>,
pub type: Option<Ticker24hrTypeEnum>,
pub symbol_status: Option<Ticker24hrSymbolStatusEnum>,
}Expand description
Request parameters for the [ticker24hr] operation.
This struct holds all of the inputs you can pass when calling
ticker24hr.
Fields
id: Option<String>Client-generated request identifier.
This field is **optional.
symbol: Option<String>The symbol parameter.
This field is **optional.
symbols: Option<Vec<String>>The symbols parameter.
This field is **optional.
type: Option<Ticker24hrTypeEnum>Ticker type. Supported values: FULL (default) or MINI
This field is **optional.
symbol_status: Option<Ticker24hrSymbolStatusEnum>Filters for symbols that have this tradingStatus. For a single symbol, a status mismatch returns error -1220 SYMBOL_DOES_NOT_MATCH_STATUS. For multiple or all symbols, non-matching ones are simply excluded from the response. Valid values: TRADING, HALT, BREAK
This field is **optional.
Implementations
Sourceimpl Ticker24hrParams
impl Ticker24hrParams
Sourcepub fn builder() -> Ticker24hrParamsBuilder
pub fn builder() -> Ticker24hrParamsBuilder
Create a builder for [ticker24hr].