pub struct TickerBookParams {
pub id: Option<String>,
pub symbol: Option<String>,
pub symbols: Option<Vec<String>>,
pub symbol_status: Option<TickerBookSymbolStatusEnum>,
}Expand description
Request parameters for the [ticker_book] operation.
This struct holds all of the inputs you can pass when calling
ticker_book.
Fields
id: Option<String>Client-generated request identifier.
This field is **optional.
symbol: Option<String>Query ticker for a single symbol
This field is **optional.
symbols: Option<Vec<String>>Query ticker for multiple symbols
This field is **optional.
symbol_status: Option<TickerBookSymbolStatusEnum>Filters for symbols that have this tradingStatus. For a single symbol, a status mismatch returns error -1220 SYMBOL_DOES_NOT_MATCH_STATUS. For multiple or all symbols, non-matching ones are simply excluded from the response. Valid values: TRADING, HALT, BREAK
This field is **optional.
Implementations
Sourceimpl TickerBookParams
impl TickerBookParams
Sourcepub fn builder() -> TickerBookParamsBuilder
pub fn builder() -> TickerBookParamsBuilder
Create a builder for [ticker_book].