pub struct TickerParams {
pub id: Option<String>,
pub symbol: Option<String>,
pub symbols: Option<Vec<String>>,
pub type: Option<TickerTypeEnum>,
pub window_size: Option<TickerWindowSizeEnum>,
pub symbol_status: Option<TickerSymbolStatusEnum>,
}Expand description
Request parameters for the [ticker] operation.
This struct holds all of the inputs you can pass when calling
ticker.
Fields
id: Option<String>Client-generated request identifier.
This field is **optional.
symbol: Option<String>Query ticker of a single symbol
This field is **optional.
symbols: Option<Vec<String>>Query ticker for multiple symbols
This field is **optional.
type: Option<TickerTypeEnum>Ticker type. Supported values: FULL (default) or MINI
This field is **optional.
window_size: Option<TickerWindowSizeEnum>Defaults to 1d if no parameter provided.
This field is **optional.
symbol_status: Option<TickerSymbolStatusEnum>Filters for symbols that have this tradingStatus. For a single symbol, a status mismatch returns error -1220 SYMBOL_DOES_NOT_MATCH_STATUS. For multiple or all symbols, non-matching ones are simply excluded from the response. Valid values: TRADING, HALT, BREAK
This field is **optional.
Implementations
Sourceimpl TickerParams
impl TickerParams
Sourcepub fn builder() -> TickerParamsBuilder
pub fn builder() -> TickerParamsBuilder
Create a builder for [ticker].