pub struct UserDataStreamUnsubscribeParams {
pub id: Option<String>,
pub subscription_id: Option<i32>,
}Expand description
Request parameters for the [user_data_stream_unsubscribe] operation.
This struct holds all of the inputs you can pass when calling
user_data_stream_unsubscribe.
Fields
id: Option<String>Unique WebSocket request ID.
This field is **optional.
subscription_id: Option<i32>When called with no parameter, this will close all subscriptions.
When called with the subscriptionId parameter, this will attempt to close the subscription with that subscription id, if it exists.
This field is **optional.
Implementations
Sourceimpl UserDataStreamUnsubscribeParams
impl UserDataStreamUnsubscribeParams
Sourcepub fn builder() -> UserDataStreamUnsubscribeParamsBuilder
pub fn builder() -> UserDataStreamUnsubscribeParamsBuilder
Create a builder for [user_data_stream_unsubscribe].