UserDataStreamUnsubscribeParamsBuilder

Struct UserDataStreamUnsubscribeParamsBuilder 

pub struct UserDataStreamUnsubscribeParamsBuilder { /* private fields */ }
Implementations

Source

impl UserDataStreamUnsubscribeParamsBuilder

pub fn id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self

Unique WebSocket request ID.

This field is **optional.

pub fn subscription_id<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self

When called with no parameter, this will close all subscriptions.
When called with the subscriptionId parameter, this will attempt to close the subscription with that subscription id, if it exists.

This field is **optional.

pub fn build(self) -> Result<UserDataStreamUnsubscribeParams, ParamBuildError>

Builds a new UserDataStreamUnsubscribeParams.

Errors

If a required field has not been initialized.