pub struct OrderListPlaceParams {Show 21 fields
pub symbol: String,
pub side: OrderListPlaceSideEnum,
pub price: Decimal,
pub quantity: Decimal,
pub id: Option<String>,
pub list_client_order_id: Option<String>,
pub limit_client_order_id: Option<String>,
pub limit_iceberg_qty: Option<Decimal>,
pub limit_strategy_id: Option<i64>,
pub limit_strategy_type: Option<i32>,
pub stop_price: Option<Decimal>,
pub trailing_delta: Option<i32>,
pub stop_client_order_id: Option<String>,
pub stop_limit_price: Option<Decimal>,
pub stop_limit_time_in_force: Option<OrderListPlaceStopLimitTimeInForceEnum>,
pub stop_iceberg_qty: Option<Decimal>,
pub stop_strategy_id: Option<i64>,
pub stop_strategy_type: Option<i32>,
pub new_order_resp_type: Option<OrderListPlaceNewOrderRespTypeEnum>,
pub self_trade_prevention_mode: Option<OrderListPlaceSelfTradePreventionModeEnum>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [order_list_place] operation.
This struct holds all of the inputs you can pass when calling
order_list_place.
Fields
symbol: StringThe symbol parameter.
This field is **required.
side: OrderListPlaceSideEnumThe side parameter.
This field is **required.
price: DecimalPrice for the limit order
This field is **required.
quantity: DecimalThe quantity parameter.
This field is **required.
id: Option<String>Unique WebSocket request ID.
This field is **optional.
list_client_order_id: Option<String>The list_client_order_id parameter.
This field is **optional.
limit_client_order_id: Option<String>Arbitrary unique ID among open orders for the limit order. Automatically generated if not sent
This field is **optional.
limit_iceberg_qty: Option<Decimal>The limit_iceberg_qty parameter.
This field is **optional.
limit_strategy_id: Option<i64>Arbitrary numeric value identifying the limit order within an order strategy.
This field is **optional.
limit_strategy_type: Option<i32>Arbitrary numeric value identifying the limit order strategy.
Values smaller than `1000000` are reserved and cannot be used.
This field is **optional.
stop_price: Option<Decimal>The stop_price parameter.
This field is **optional.
trailing_delta: Option<i32>This field is **optional.
stop_client_order_id: Option<String>Arbitrary unique ID among open orders for the stop order. Automatically generated if not sent
This field is **optional.
stop_limit_price: Option<Decimal>The stop_limit_price parameter.
This field is **optional.
stop_limit_time_in_force: Option<OrderListPlaceStopLimitTimeInForceEnum>The stop_limit_time_in_force parameter.
This field is **optional.
stop_iceberg_qty: Option<Decimal>The stop_iceberg_qty parameter.
This field is **optional.
stop_strategy_id: Option<i64>Arbitrary numeric value identifying the stop order within an order strategy.
This field is **optional.
stop_strategy_type: Option<i32>Arbitrary numeric value identifying the stop order strategy.
Values smaller than `1000000` are reserved and cannot be used.
This field is **optional.
new_order_resp_type: Option<OrderListPlaceNewOrderRespTypeEnum>The new_order_resp_type parameter.
This field is **optional.
self_trade_prevention_mode: Option<OrderListPlaceSelfTradePreventionModeEnum>The self_trade_prevention_mode parameter.
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OrderListPlaceParams
impl OrderListPlaceParams
Sourcepub fn builder(
symbol: String,
side: OrderListPlaceSideEnum,
price: Decimal,
quantity: Decimal,
) -> OrderListPlaceParamsBuilder
pub fn builder( symbol: String, side: OrderListPlaceSideEnum, price: Decimal, quantity: Decimal, ) -> OrderListPlaceParamsBuilder
Create a builder for [order_list_place].
Required parameters:
symbol— Stringside— Stringprice— Price for the limit orderquantity—rust_decimal::Decimal