pub struct OrderTestParamsBuilder { /* private fields */ }Expand description
Builder for OrderTestParams.
Implementations
Sourceimpl OrderTestParamsBuilder
impl OrderTestParamsBuilder
Sourcepub fn symbol<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn symbol<VALUE: Into<String>>(self, value: VALUE) -> Self
The symbol parameter.
This field is **required.
Sourcepub fn side<VALUE: Into<OrderTestSideEnum>>(self, value: VALUE) -> Self
pub fn side<VALUE: Into<OrderTestSideEnum>>(self, value: VALUE) -> Self
The side parameter.
This field is **required.
Sourcepub fn type<VALUE: Into<OrderTestTypeEnum>>(self, value: VALUE) -> Self
pub fn type<VALUE: Into<OrderTestTypeEnum>>(self, value: VALUE) -> Self
The r#type parameter.
This field is **required.
Sourcepub fn id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
Unique WebSocket request ID.
This field is **optional.
Sourcepub fn compute_commission_rates<VALUE: Into<Option<bool>>>(
self,
value: VALUE,
) -> Self
pub fn compute_commission_rates<VALUE: Into<Option<bool>>>( self, value: VALUE, ) -> Self
Default: false
See Commissions FAQ to learn more.
This field is **optional.
Sourcepub fn time_in_force<VALUE: Into<Option<OrderTestTimeInForceEnum>>>(
self,
value: VALUE,
) -> Self
pub fn time_in_force<VALUE: Into<Option<OrderTestTimeInForceEnum>>>( self, value: VALUE, ) -> Self
The time_in_force parameter.
This field is **optional.
Sourcepub fn price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
The price parameter.
This field is **optional.
Sourcepub fn quantity<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn quantity<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
The quantity parameter.
This field is **optional.
Sourcepub fn quote_order_qty<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn quote_order_qty<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
The quote_order_qty parameter.
This field is **optional.
Sourcepub fn new_client_order_id<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn new_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
The new client order ID for the order after being amended.
If not sent, one will be randomly generated.
It is possible to reuse the current clientOrderId by sending it as the newClientOrderId.
This field is **optional.
Sourcepub fn new_order_resp_type<VALUE: Into<Option<OrderTestNewOrderRespTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn new_order_resp_type<VALUE: Into<Option<OrderTestNewOrderRespTypeEnum>>>( self, value: VALUE, ) -> Self
The new_order_resp_type parameter.
This field is **optional.
Sourcepub fn stop_price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn stop_price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
The stop_price parameter.
This field is **optional.
Sourcepub fn trailing_delta<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
pub fn trailing_delta<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
This field is **optional.
Sourcepub fn iceberg_qty<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn iceberg_qty<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
The iceberg_qty parameter.
This field is **optional.
Sourcepub fn strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
pub fn strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
Arbitrary numeric value identifying the order within an order strategy.
This field is **optional.
Sourcepub fn strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
pub fn strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
Arbitrary numeric value identifying the order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
Sourcepub fn self_trade_prevention_mode<VALUE: Into<Option<OrderTestSelfTradePreventionModeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn self_trade_prevention_mode<VALUE: Into<Option<OrderTestSelfTradePreventionModeEnum>>>( self, value: VALUE, ) -> Self
The self_trade_prevention_mode parameter.
This field is **optional.
Sourcepub fn peg_price_type<VALUE: Into<Option<OrderTestPegPriceTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn peg_price_type<VALUE: Into<Option<OrderTestPegPriceTypeEnum>>>( self, value: VALUE, ) -> Self
The peg_price_type parameter.
This field is **optional.
Sourcepub fn peg_offset_value<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
pub fn peg_offset_value<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
Price level to peg the price to (max: 100) See Pegged Orders
This field is **optional.
Sourcepub fn peg_offset_type<VALUE: Into<Option<OrderTestPegOffsetTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn peg_offset_type<VALUE: Into<Option<OrderTestPegOffsetTypeEnum>>>( self, value: VALUE, ) -> Self
The peg_offset_type parameter.
This field is **optional.
Sourcepub fn recv_window<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn recv_window<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.