pub struct QueryManagedSubAccountTransferLogMasterAccountTradingParams {
pub email: String,
pub start_time: i64,
pub end_time: i64,
pub page: i64,
pub limit: i64,
pub transfers: Option<String>,
pub transfer_function_account_type: Option<String>,
}Expand description
Request parameters for the [query_managed_sub_account_transfer_log_master_account_trading] operation.
This struct holds all of the inputs you can pass when calling
query_managed_sub_account_transfer_log_master_account_trading.
Fields
email: StringThis field is **required.
start_time: i64Start Time
This field is **required.
end_time: i64End Time (The start time and end time interval cannot exceed half a year)
This field is **required.
page: i64Page
This field is **required.
limit: i64Limit (Max: 500)
This field is **required.
transfers: Option<String>Transfer Direction (from/to)
This field is **optional.
transfer_function_account_type: Option<String>Transfer function account type (SPOT/MARGIN/ISOLATED_MARGIN/USDT_FUTURE/COIN_FUTURE)
This field is **optional.
Implementations
Sourceimpl QueryManagedSubAccountTransferLogMasterAccountTradingParams
impl QueryManagedSubAccountTransferLogMasterAccountTradingParams
Sourcepub fn builder(
email: String,
start_time: i64,
end_time: i64,
page: i64,
limit: i64,
) -> QueryManagedSubAccountTransferLogMasterAccountTradingParamsBuilder
pub fn builder( email: String, start_time: i64, end_time: i64, page: i64, limit: i64, ) -> QueryManagedSubAccountTransferLogMasterAccountTradingParamsBuilder
Create a builder for [query_managed_sub_account_transfer_log_master_account_trading].
Required parameters:
email— Sub-account emailstart_time— Start Timeend_time— End Time (The start time and end time interval cannot exceed half a year)page— Pagelimit— Limit (Max: 500)