pub struct FetchDepositAddressListWithNetworkParams {
pub coin: String,
pub network: Option<String>,
}Expand description
Request parameters for the [fetch_deposit_address_list_with_network] operation.
This struct holds all of the inputs you can pass when calling
fetch_deposit_address_list_with_network.
Fields
coin: StringCoin name
This field is **required.
network: Option<String>If network is not send, return with default network of the coin. You can get network and isDefault in networkList in the response of Get /sapi/v1/capital/config/getall
This field is **optional.
Implementations
Sourceimpl FetchDepositAddressListWithNetworkParams
impl FetchDepositAddressListWithNetworkParams
Sourcepub fn builder(coin: String) -> FetchDepositAddressListWithNetworkParamsBuilder
pub fn builder(coin: String) -> FetchDepositAddressListWithNetworkParamsBuilder
Create a builder for [fetch_deposit_address_list_with_network].
Required parameters:
coin— Coin name