pub struct QueryUserDelegationHistoryParams {
pub email: String,
pub start_time: i64,
pub end_time: i64,
pub type: Option<String>,
pub asset: Option<String>,
pub current: Option<i64>,
pub size: Option<i64>,
pub recv_window: Option<i64>,
}Expand description
Request parameters for the [query_user_delegation_history] operation.
This struct holds all of the inputs you can pass when calling
query_user_delegation_history.
Fields
email: StringThe email parameter.
This field is **required.
start_time: i64The start_time parameter.
This field is **required.
end_time: i64The end_time parameter.
This field is **required.
type: Option<String>Delegate/Undelegate
This field is **optional.
asset: Option<String>If asset is blank, then query all positive assets user have.
This field is **optional.
current: Option<i64>current page, default 1, the min value is 1
This field is **optional.
size: Option<i64>page size, default 10, the max value is 100
This field is **optional.
recv_window: Option<i64>The recv_window parameter.
This field is **optional.
Implementations