pub struct UserAssetParams {
pub asset: Option<String>,
pub need_btc_valuation: Option<bool>,
pub recv_window: Option<i64>,
}Expand description
Request parameters for the [user_asset] operation.
This struct holds all of the inputs you can pass when calling
user_asset.
Fields
asset: Option<String>If asset is blank, then query all positive assets user have.
This field is **optional.
need_btc_valuation: Option<bool>Whether need btc valuation or not.
This field is **optional.
recv_window: Option<i64>The recv_window parameter.
This field is **optional.
Implementations
Sourceimpl UserAssetParams
impl UserAssetParams
Sourcepub fn builder() -> UserAssetParamsBuilder
pub fn builder() -> UserAssetParamsBuilder
Create a builder for [user_asset].