WithdrawParams

Struct WithdrawParams 

pub struct WithdrawParams {
    pub coin: String,
    pub address: String,
    pub amount: Decimal,
    pub withdraw_order_id: Option<String>,
    pub network: Option<String>,
    pub address_tag: Option<String>,
    pub transaction_fee_flag: Option<bool>,
    pub name: Option<String>,
    pub wallet_type: Option<i64>,
    pub recv_window: Option<i64>,
}
Request parameters for the [withdraw] operation.

This struct holds all of the inputs you can pass when calling withdraw.

Fields

coin: String

The coin parameter.

This field is **required.

address: String

The address parameter.

This field is **required.

amount: Decimal

The amount parameter.

This field is **required.

withdraw_order_id: Option<String>

client side id for withdrawal, if provided in POST /sapi/v1/capital/withdraw/apply, can be used here for query.

This field is **optional.

network: Option<String>

The network parameter.

This field is **optional.

address_tag: Option<String>

Secondary address identifier for coins like XRP,XMR etc.

This field is **optional.

transaction_fee_flag: Option<bool>

When making internal transfer, true for returning the fee to the destination account; false for returning the fee back to the departure account. Default false.

This field is **optional.

name: Option<String>

Description of the address. Address book cap is 200, space in name should be encoded into %20

This field is **optional.

wallet_type: Option<i64>

The wallet type for withdraw,0-spot wallet ,1-funding wallet. Default walletType is the current “selected wallet” under wallet->Fiat and Spot/Funding->Deposit

This field is **optional.

recv_window: Option<i64>

The recv_window parameter.

This field is **optional.

Implementations

Source

impl WithdrawParams

pub fn builder( coin: String, address: String, amount: Decimal, ) -> WithdrawParamsBuilder

Create a builder for [withdraw].

Required parameters:

  • coin — String
  • address — String
  • amountrust_decimal::Decimal