pub struct AlphaWsStreams {}Expand description
Represents the Alpha WebSocket Streams client for interacting with the Binance Alpha WebSocket Streams.
This struct provides methods to create WebSocket Streams clients for production environments.
Implementations
Sourceimpl AlphaWsStreams
impl AlphaWsStreams
Sourcepub fn from_config(
config: ConfigurationWebsocketStreams,
) -> WebsocketStreamsHandle
pub fn from_config( config: ConfigurationWebsocketStreams, ) -> WebsocketStreamsHandle
Creates a WebSocket streams client configured with the given settings.
If no WS URL is specified in the configuration, defaults to the production Alpha WebSocket Streams URL.
Arguments
config- Configuration for the WebSocket streams client
Returns
A new WebSocket streams client configured with the provided settings
Sourcepub fn production(
config: ConfigurationWebsocketStreams,
) -> WebsocketStreamsHandle
pub fn production( config: ConfigurationWebsocketStreams, ) -> WebsocketStreamsHandle