pub struct RestApi { /* private fields */ }Implementations
Sourceimpl RestApi
impl RestApi
pub fn new(configuration: ConfigurationRestApi) -> Self
Sourcepub async fn send_request<R: DeserializeOwned + Send + 'static>(
&self,
endpoint: &str,
method: Method,
query_params: BTreeMap<String, Value>,
body_params: BTreeMap<String, Value>,
) -> Result<RestApiResponse<R>>
pub async fn send_request<R: DeserializeOwned + Send + 'static>( &self, endpoint: &str, method: Method, query_params: BTreeMap<String, Value>, body_params: BTreeMap<String, Value>, ) -> Result<RestApiResponse<R>>
Send an unsigned request to the API
Arguments
endpoint- The API endpoint to send the request tomethod- The HTTP method to use for the requestquery_params- A map of query parameters to send with the requestbody_params- A map of body parameters to send with the request
Returns
A RestApiResponse containing the deserialized response data on success, or an error if the request fails
Errors
Returns an anyhow::Error if the HTTP request fails or if parsing the response fails
Sourcepub async fn send_signed_request<R: DeserializeOwned + Send + 'static>(
&self,
endpoint: &str,
method: Method,
query_params: BTreeMap<String, Value>,
body_params: BTreeMap<String, Value>,
) -> Result<RestApiResponse<R>>
pub async fn send_signed_request<R: DeserializeOwned + Send + 'static>( &self, endpoint: &str, method: Method, query_params: BTreeMap<String, Value>, body_params: BTreeMap<String, Value>, ) -> Result<RestApiResponse<R>>
Send a signed request to the API
Arguments
endpoint- The API endpoint to send the request tomethod- The HTTP method to use for the requestquery_params- A map of query parameters to send with the requestbody_params- A map of body parameters to send with the request
Returns
A RestApiResponse containing the deserialized response data on success, or an error if the request fails
Errors
Returns an anyhow::Error if the HTTP request fails or if parsing the response fails
Sourcepub async fn get_c2_c_trade_history(
&self,
params: GetC2CTradeHistoryParams,
) -> Result<RestApiResponse<GetC2CTradeHistoryResponse>>
pub async fn get_c2_c_trade_history( &self, params: GetC2CTradeHistoryParams, ) -> Result<RestApiResponse<GetC2CTradeHistoryResponse>>
Get C2C Trade History (USER_DATA)
Get C2C Trade History
- The max interval between startTimestamp and endTimestamp is 30 days.
- If startTimestamp and endTimestamp are not sent, the recent 30 days’ data will be returned.
- You can only view data from the past 6 months. To see all C2C orders, please check https://c2c.binance.com/en/fiatOrder
Weight: 1
Arguments
params:GetC2CTradeHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetC2CTradeHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.