pub struct SendQuoteRequestParamsBuilder { /* private fields */ }Expand description
Builder for SendQuoteRequestParams.
Implementations
Sourceimpl SendQuoteRequestParamsBuilder
impl SendQuoteRequestParamsBuilder
Sourcepub fn from_asset<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn from_asset<VALUE: Into<String>>(self, value: VALUE) -> Self
The from_asset parameter.
This field is **required.
Sourcepub fn to_asset<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn to_asset<VALUE: Into<String>>(self, value: VALUE) -> Self
The to_asset parameter.
This field is **required.
Sourcepub fn from_amount<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn from_amount<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
When specified, it is the amount you will be debited after the conversion
This field is **optional.
Sourcepub fn to_amount<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn to_amount<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
When specified, it is the amount you will be credited after the conversion
This field is **optional.
Sourcepub fn wallet_type<VALUE: Into<Option<SendQuoteRequestWalletTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn wallet_type<VALUE: Into<Option<SendQuoteRequestWalletTypeEnum>>>( self, value: VALUE, ) -> Self
Wallet to use for payment. Supported values: SPOT, FUNDING, EARN.
Combined wallets also supported: SPOT_FUNDING, FUNDING_EARN, SPOT_FUNDING_EARN, SPOT_EARN. Default is SPOT.
This field is **optional.
Sourcepub fn valid_time<VALUE: Into<Option<SendQuoteRequestValidTimeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn valid_time<VALUE: Into<Option<SendQuoteRequestValidTimeEnum>>>( self, value: VALUE, ) -> Self
Quote valid duration. Supported values: 10s, 30s, 1m. Default is 10s.
This field is **optional.
Sourcepub fn recv_window<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
pub fn recv_window<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
Request validity window in milliseconds
This field is **optional.
Sourcepub fn build(self) -> Result<SendQuoteRequestParams, ParamBuildError>
pub fn build(self) -> Result<SendQuoteRequestParams, ParamBuildError>