pub struct CreateSpecialKeyParams {
pub api_name: String,
pub symbol: Option<String>,
pub ip: Option<String>,
pub public_key: Option<String>,
pub permission_mode: Option<String>,
pub recv_window: Option<i64>,
}Expand description
Request parameters for the [create_special_key] operation.
This struct holds all of the inputs you can pass when calling
create_special_key.
Fields
api_name: StringThe api_name parameter.
This field is **required.
symbol: Option<String>isolated margin pair
This field is **optional.
ip: Option<String>Can be added in batches, separated by commas. Max 30 for an API key
This field is **optional.
public_key: Option<String>- If publicKey is inputted it will create an RSA or Ed25519 key.
2. Need to be encoded to URL-encoded format
This field is **optional.
permission_mode: Option<String>This parameter is only for the Ed25519 API key, and does not effact for other encryption methods. The value can be TRADE (TRADE for all permissions) or READ (READ for USER_DATA, FIX_API_READ_ONLY). The default value is TRADE.
This field is **optional.
recv_window: Option<i64>No more than 60000
This field is **optional.
Implementations
Sourceimpl CreateSpecialKeyParams
impl CreateSpecialKeyParams
Sourcepub fn builder(api_name: String) -> CreateSpecialKeyParamsBuilder
pub fn builder(api_name: String) -> CreateSpecialKeyParamsBuilder
Create a builder for [create_special_key].
Required parameters:
api_name— String