pub struct RestApi { /* private fields */ }Implementations
Sourceimpl RestApi
impl RestApi
pub fn new(configuration: ConfigurationRestApi) -> Self
Sourcepub async fn send_request<R: DeserializeOwned + Send + 'static>(
&self,
endpoint: &str,
method: Method,
query_params: BTreeMap<String, Value>,
body_params: BTreeMap<String, Value>,
) -> Result<RestApiResponse<R>>
pub async fn send_request<R: DeserializeOwned + Send + 'static>( &self, endpoint: &str, method: Method, query_params: BTreeMap<String, Value>, body_params: BTreeMap<String, Value>, ) -> Result<RestApiResponse<R>>
Send an unsigned request to the API
Arguments
endpoint- The API endpoint to send the request tomethod- The HTTP method to use for the requestquery_params- A map of query parameters to send with the requestbody_params- A map of body parameters to send with the request
Returns
A RestApiResponse containing the deserialized response data on success, or an error if the request fails
Errors
Returns an anyhow::Error if the HTTP request fails or if parsing the response fails
Sourcepub async fn send_signed_request<R: DeserializeOwned + Send + 'static>(
&self,
endpoint: &str,
method: Method,
query_params: BTreeMap<String, Value>,
body_params: BTreeMap<String, Value>,
) -> Result<RestApiResponse<R>>
pub async fn send_signed_request<R: DeserializeOwned + Send + 'static>( &self, endpoint: &str, method: Method, query_params: BTreeMap<String, Value>, body_params: BTreeMap<String, Value>, ) -> Result<RestApiResponse<R>>
Send a signed request to the API
Arguments
endpoint- The API endpoint to send the request tomethod- The HTTP method to use for the requestquery_params- A map of query parameters to send with the requestbody_params- A map of body parameters to send with the request
Returns
A RestApiResponse containing the deserialized response data on success, or an error if the request fails
Errors
Returns an anyhow::Error if the HTTP request fails or if parsing the response fails
Sourcepub async fn get_bfusd_account(
&self,
params: GetBfusdAccountParams,
) -> Result<RestApiResponse<GetBfusdAccountResponse>>
pub async fn get_bfusd_account( &self, params: GetBfusdAccountParams, ) -> Result<RestApiResponse<GetBfusdAccountResponse>>
Get BFUSD Account (USER_DATA)
Get BFUSD account information.
Weight: 150
Arguments
params:GetBfusdAccountParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetBfusdAccountResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_bfusd_quota_details(
&self,
params: GetBfusdQuotaDetailsParams,
) -> Result<RestApiResponse<GetBfusdQuotaDetailsResponse>>
pub async fn get_bfusd_quota_details( &self, params: GetBfusdQuotaDetailsParams, ) -> Result<RestApiResponse<GetBfusdQuotaDetailsResponse>>
Get BFUSD Quota Details (USER_DATA)
Get BFUSD quota details including subscription quota, fast redemption quota and standard redemption quota.
Weight: 150
Arguments
params:GetBfusdQuotaDetailsParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetBfusdQuotaDetailsResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_bfusd_rate_history(
&self,
params: GetBfusdRateHistoryParams,
) -> Result<RestApiResponse<GetBfusdRateHistoryResponse>>
pub async fn get_bfusd_rate_history( &self, params: GetBfusdRateHistoryParams, ) -> Result<RestApiResponse<GetBfusdRateHistoryResponse>>
Get BFUSD Rate History (USER_DATA)
Get BFUSD rate history sorted by descending order.
- The time between
startTimeandendTimecannot be longer than 6 months. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent,endTimewill default to current time, and results fromstartTimeonward will be returned. - If
endTimeis sent butstartTimeis not sent,startTimedefaults to the current time minus one month, and data betweenstartTimeandendTimewill be returned.
Weight: 150
Arguments
params:GetBfusdRateHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetBfusdRateHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_bfusd_redemption_history(
&self,
params: GetBfusdRedemptionHistoryParams,
) -> Result<RestApiResponse<GetBfusdRedemptionHistoryResponse>>
pub async fn get_bfusd_redemption_history( &self, params: GetBfusdRedemptionHistoryParams, ) -> Result<RestApiResponse<GetBfusdRedemptionHistoryResponse>>
Get BFUSD Redemption History (USER_DATA)
Get BFUSD redemption history.
- The time between
startTimeandendTimecannot be longer than 6 months. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent,endTimewill default to current time, and results fromstartTimeonward will be returned. - If
endTimeis sent butstartTimeis not sent,startTimedefaults to the current time minus one month, and data betweenstartTimeandendTimewill be returned.
Weight: 150
Arguments
params:GetBfusdRedemptionHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetBfusdRedemptionHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_bfusd_rewards_history(
&self,
params: GetBfusdRewardsHistoryParams,
) -> Result<RestApiResponse<GetBfusdRewardsHistoryResponse>>
pub async fn get_bfusd_rewards_history( &self, params: GetBfusdRewardsHistoryParams, ) -> Result<RestApiResponse<GetBfusdRewardsHistoryResponse>>
Get BFUSD Rewards History (USER_DATA)
Get BFUSD rewards history.
- The time between
startTimeandendTimecannot be longer than 6 months. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent,endTimewill default to current time, and results fromstartTimeonward will be returned. - If
endTimeis sent butstartTimeis not sent,startTimedefaults to the current time minus one month, and data betweenstartTimeandendTimewill be returned.
Weight: 150
Arguments
params:GetBfusdRewardsHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetBfusdRewardsHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_bfusd_subscription_history(
&self,
params: GetBfusdSubscriptionHistoryParams,
) -> Result<RestApiResponse<GetBfusdSubscriptionHistoryResponse>>
pub async fn get_bfusd_subscription_history( &self, params: GetBfusdSubscriptionHistoryParams, ) -> Result<RestApiResponse<GetBfusdSubscriptionHistoryResponse>>
Get BFUSD subscription history(USER_DATA)
Get BFUSD subscription history
- The time between
startTimeandendTimecannot be longer than 6 months. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent,endTimewill default to current time, and results fromstartTimeonward will be returned. - If
endTimeis sent butstartTimeis not sent,startTimedefaults to the current time advanced by one month, and data betweenstartTimeandendTimewill be returned.
Weight: 150
Arguments
params:GetBfusdSubscriptionHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetBfusdSubscriptionHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn redeem_bfusd(
&self,
params: RedeemBfusdParams,
) -> Result<RestApiResponse<RedeemBfusdResponse>>
pub async fn redeem_bfusd( &self, params: RedeemBfusdParams, ) -> Result<RestApiResponse<RedeemBfusdResponse>>
Redeem BFUSD(TRADE)
Redeem BFUSD to USDT
- You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.
Weight: 150
Arguments
params:RedeemBfusdParamsThe parameters for this operation.
Returns
RestApiResponse<models::RedeemBfusdResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn subscribe_bfusd(
&self,
params: SubscribeBfusdParams,
) -> Result<RestApiResponse<SubscribeBfusdResponse>>
pub async fn subscribe_bfusd( &self, params: SubscribeBfusdParams, ) -> Result<RestApiResponse<SubscribeBfusdResponse>>
Subscribe BFUSD(TRADE)
Subscribe BFUSD
- You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.
Weight: 150
Arguments
params:SubscribeBfusdParamsThe parameters for this operation.
Returns
RestApiResponse<models::SubscribeBfusdResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_collateral_record(
&self,
params: GetCollateralRecordParams,
) -> Result<RestApiResponse<GetCollateralRecordResponse>>
pub async fn get_collateral_record( &self, params: GetCollateralRecordParams, ) -> Result<RestApiResponse<GetCollateralRecordResponse>>
Get Collateral Record(USER_DATA)
Get Collateral Record
- The time between
startTimeandendTimecannot be longer than 30 days. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent, the next 30 days’ data beginning fromstartTimewill be returned. - If
endTimeis sent butstartTimeis not sent, the 30 days’ data beforeendTimewill be returned.
Weight: 1
Arguments
params:GetCollateralRecordParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetCollateralRecordResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_flexible_personal_left_quota(
&self,
params: GetFlexiblePersonalLeftQuotaParams,
) -> Result<RestApiResponse<GetFlexiblePersonalLeftQuotaResponse>>
pub async fn get_flexible_personal_left_quota( &self, params: GetFlexiblePersonalLeftQuotaParams, ) -> Result<RestApiResponse<GetFlexiblePersonalLeftQuotaResponse>>
Get Flexible Personal Left Quota(USER_DATA)
Get Flexible Personal Left Quota
Weight: 150
Arguments
params:GetFlexiblePersonalLeftQuotaParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetFlexiblePersonalLeftQuotaResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_flexible_product_position(
&self,
params: GetFlexibleProductPositionParams,
) -> Result<RestApiResponse<GetFlexibleProductPositionResponse>>
pub async fn get_flexible_product_position( &self, params: GetFlexibleProductPositionParams, ) -> Result<RestApiResponse<GetFlexibleProductPositionResponse>>
Get Flexible Product Position(USER_DATA)
Get Flexible Product Position
Weight: 150
Arguments
params:GetFlexibleProductPositionParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetFlexibleProductPositionResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_flexible_redemption_record(
&self,
params: GetFlexibleRedemptionRecordParams,
) -> Result<RestApiResponse<GetFlexibleRedemptionRecordResponse>>
pub async fn get_flexible_redemption_record( &self, params: GetFlexibleRedemptionRecordParams, ) -> Result<RestApiResponse<GetFlexibleRedemptionRecordResponse>>
Get Flexible Redemption Record(USER_DATA)
Get Flexible Redemption Record
- The time between
startTimeandendTimecannot be longer than 30 days. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent, the next 30 days’ data beginning fromstartTimewill be returned. - If
endTimeis sent butstartTimeis not sent, the 30 days’ data beforeendTimewill be returned.
Weight: 150
Arguments
params:GetFlexibleRedemptionRecordParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetFlexibleRedemptionRecordResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_flexible_rewards_history(
&self,
params: GetFlexibleRewardsHistoryParams,
) -> Result<RestApiResponse<GetFlexibleRewardsHistoryResponse>>
pub async fn get_flexible_rewards_history( &self, params: GetFlexibleRewardsHistoryParams, ) -> Result<RestApiResponse<GetFlexibleRewardsHistoryResponse>>
Get Flexible Rewards History(USER_DATA)
Get Flexible Rewards History
- The time between
startTimeandendTimecannot be longer than 30 days. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent, the next 30 days’ data beginning fromstartTimewill be returned. - If
endTimeis sent butstartTimeis not sent, the 30 days’ data beforeendTimewill be returned.
Weight: 150
Arguments
params:GetFlexibleRewardsHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetFlexibleRewardsHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_flexible_subscription_preview(
&self,
params: GetFlexibleSubscriptionPreviewParams,
) -> Result<RestApiResponse<GetFlexibleSubscriptionPreviewResponse>>
pub async fn get_flexible_subscription_preview( &self, params: GetFlexibleSubscriptionPreviewParams, ) -> Result<RestApiResponse<GetFlexibleSubscriptionPreviewResponse>>
Get Flexible Subscription Preview(USER_DATA)
Get Flexible Subscription Preview
Weight: 150
Arguments
params:GetFlexibleSubscriptionPreviewParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetFlexibleSubscriptionPreviewResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_flexible_subscription_record(
&self,
params: GetFlexibleSubscriptionRecordParams,
) -> Result<RestApiResponse<GetFlexibleSubscriptionRecordResponse>>
pub async fn get_flexible_subscription_record( &self, params: GetFlexibleSubscriptionRecordParams, ) -> Result<RestApiResponse<GetFlexibleSubscriptionRecordResponse>>
Get Flexible Subscription Record(USER_DATA)
Get Flexible Subscription Record
- The time between
startTimeandendTimecannot be longer than 30 days. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent, the next 30 days’ data beginning fromstartTimewill be returned. - If
endTimeis sent butstartTimeis not sent, the 30 days’ data beforeendTimewill be returned.
Weight: 150
Arguments
params:GetFlexibleSubscriptionRecordParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetFlexibleSubscriptionRecordResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_locked_personal_left_quota(
&self,
params: GetLockedPersonalLeftQuotaParams,
) -> Result<RestApiResponse<GetLockedPersonalLeftQuotaResponse>>
pub async fn get_locked_personal_left_quota( &self, params: GetLockedPersonalLeftQuotaParams, ) -> Result<RestApiResponse<GetLockedPersonalLeftQuotaResponse>>
Get Locked Personal Left Quota(USER_DATA)
Get Locked Personal Left Quota
Weight: 150
Arguments
params:GetLockedPersonalLeftQuotaParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetLockedPersonalLeftQuotaResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_locked_product_position(
&self,
params: GetLockedProductPositionParams,
) -> Result<RestApiResponse<GetLockedProductPositionResponse>>
pub async fn get_locked_product_position( &self, params: GetLockedProductPositionParams, ) -> Result<RestApiResponse<GetLockedProductPositionResponse>>
Get Locked Product Position
Get Locked Product Position
Weight: 150
Arguments
params:GetLockedProductPositionParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetLockedProductPositionResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_locked_redemption_record(
&self,
params: GetLockedRedemptionRecordParams,
) -> Result<RestApiResponse<GetLockedRedemptionRecordResponse>>
pub async fn get_locked_redemption_record( &self, params: GetLockedRedemptionRecordParams, ) -> Result<RestApiResponse<GetLockedRedemptionRecordResponse>>
Get Locked Redemption Record(USER_DATA)
Get Locked Redemption Record
- The time between
startTimeandendTimecannot be longer than 30 days. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent, the next 30 days’ data beginning fromstartTimewill be returned. - If
endTimeis sent butstartTimeis not sent, the 30 days’ data beforeendTimewill be returned.
Weight: 150
Arguments
params:GetLockedRedemptionRecordParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetLockedRedemptionRecordResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_locked_rewards_history(
&self,
params: GetLockedRewardsHistoryParams,
) -> Result<RestApiResponse<GetLockedRewardsHistoryResponse>>
pub async fn get_locked_rewards_history( &self, params: GetLockedRewardsHistoryParams, ) -> Result<RestApiResponse<GetLockedRewardsHistoryResponse>>
Get Locked Rewards History(USER_DATA)
Get Locked Rewards History
- The time between
startTimeandendTimecannot be longer than 30 days. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent, the next 30 days’ data beginning fromstartTimewill be returned. - If
endTimeis sent butstartTimeis not sent, the 30 days’ data beforeendTimewill be returned.
Weight: 150
Arguments
params:GetLockedRewardsHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetLockedRewardsHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_locked_subscription_preview(
&self,
params: GetLockedSubscriptionPreviewParams,
) -> Result<RestApiResponse<Vec<GetLockedSubscriptionPreviewResponseInner>>>
pub async fn get_locked_subscription_preview( &self, params: GetLockedSubscriptionPreviewParams, ) -> Result<RestApiResponse<Vec<GetLockedSubscriptionPreviewResponseInner>>>
Get Locked Subscription Preview(USER_DATA)
Get Locked Subscription Preview
Weight: 150
Arguments
params:GetLockedSubscriptionPreviewParamsThe parameters for this operation.
Returns
RestApiResponse<Vec<models::GetLockedSubscriptionPreviewResponseInner>> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_locked_subscription_record(
&self,
params: GetLockedSubscriptionRecordParams,
) -> Result<RestApiResponse<GetLockedSubscriptionRecordResponse>>
pub async fn get_locked_subscription_record( &self, params: GetLockedSubscriptionRecordParams, ) -> Result<RestApiResponse<GetLockedSubscriptionRecordResponse>>
Get Locked Subscription Record(USER_DATA)
Get Locked Subscription Record
- The time between
startTimeandendTimecannot be longer than 30 days. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent, the next 30 days’ data beginning fromstartTimewill be returned. - If
endTimeis sent butstartTimeis not sent, the 30 days’ data beforeendTimewill be returned.
Weight: 150
Arguments
params:GetLockedSubscriptionRecordParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetLockedSubscriptionRecordResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_rate_history(
&self,
params: GetRateHistoryParams,
) -> Result<RestApiResponse<GetRateHistoryResponse>>
pub async fn get_rate_history( &self, params: GetRateHistoryParams, ) -> Result<RestApiResponse<GetRateHistoryResponse>>
Get Rate History(USER_DATA)
Get Rate History
- The time between startTime and endTime cannot be longer than 1 year.
- If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent, the next 30 days’ data beginning fromstartTimewill be returned. - If
endTimeis sent butstartTimeis not sent, the 30 days’ data beforeendTimewill be returned.
Weight: 150
Arguments
params:GetRateHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetRateHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_simple_earn_flexible_product_list(
&self,
params: GetSimpleEarnFlexibleProductListParams,
) -> Result<RestApiResponse<GetSimpleEarnFlexibleProductListResponse>>
pub async fn get_simple_earn_flexible_product_list( &self, params: GetSimpleEarnFlexibleProductListParams, ) -> Result<RestApiResponse<GetSimpleEarnFlexibleProductListResponse>>
Get Simple Earn Flexible Product List(USER_DATA)
Get available Simple Earn flexible product list
Weight: 150
Arguments
params:GetSimpleEarnFlexibleProductListParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetSimpleEarnFlexibleProductListResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_simple_earn_locked_product_list(
&self,
params: GetSimpleEarnLockedProductListParams,
) -> Result<RestApiResponse<GetSimpleEarnLockedProductListResponse>>
pub async fn get_simple_earn_locked_product_list( &self, params: GetSimpleEarnLockedProductListParams, ) -> Result<RestApiResponse<GetSimpleEarnLockedProductListResponse>>
Get Simple Earn Locked Product List(USER_DATA)
Get Simple Earn Locked Product List
- Get available Simple Earn locked product list
Weight: 150
Arguments
params:GetSimpleEarnLockedProductListParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetSimpleEarnLockedProductListResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn redeem_flexible_product(
&self,
params: RedeemFlexibleProductParams,
) -> Result<RestApiResponse<RedeemFlexibleProductResponse>>
pub async fn redeem_flexible_product( &self, params: RedeemFlexibleProductParams, ) -> Result<RestApiResponse<RedeemFlexibleProductResponse>>
Redeem Flexible Product(TRADE)
Redeem Flexible Product
- You need to open
Enable Spot & Margin Tradingpermission for the API Key which requests this endpoint.
Weight: 1
Arguments
params:RedeemFlexibleProductParamsThe parameters for this operation.
Returns
RestApiResponse<models::RedeemFlexibleProductResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn redeem_locked_product(
&self,
params: RedeemLockedProductParams,
) -> Result<RestApiResponse<RedeemLockedProductResponse>>
pub async fn redeem_locked_product( &self, params: RedeemLockedProductParams, ) -> Result<RestApiResponse<RedeemLockedProductResponse>>
Redeem Locked Product(TRADE)
Redeem Locked Product
- You need to open
Enable Spot & Margin Tradingpermission for the API Key which requests this endpoint.
Weight: 1/3s per account
Arguments
params:RedeemLockedProductParamsThe parameters for this operation.
Returns
RestApiResponse<models::RedeemLockedProductResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn set_flexible_auto_subscribe(
&self,
params: SetFlexibleAutoSubscribeParams,
) -> Result<RestApiResponse<SetFlexibleAutoSubscribeResponse>>
pub async fn set_flexible_auto_subscribe( &self, params: SetFlexibleAutoSubscribeParams, ) -> Result<RestApiResponse<SetFlexibleAutoSubscribeResponse>>
Set Flexible Auto Subscribe(USER_DATA)
Set Flexible Auto Subscribe
Weight: 150
Arguments
params:SetFlexibleAutoSubscribeParamsThe parameters for this operation.
Returns
RestApiResponse<models::SetFlexibleAutoSubscribeResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn set_locked_auto_subscribe(
&self,
params: SetLockedAutoSubscribeParams,
) -> Result<RestApiResponse<SetLockedAutoSubscribeResponse>>
pub async fn set_locked_auto_subscribe( &self, params: SetLockedAutoSubscribeParams, ) -> Result<RestApiResponse<SetLockedAutoSubscribeResponse>>
Set Locked Auto Subscribe(USER_DATA)
Set locked auto subscribe
Weight: 150
Arguments
params:SetLockedAutoSubscribeParamsThe parameters for this operation.
Returns
RestApiResponse<models::SetLockedAutoSubscribeResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn set_locked_product_redeem_option(
&self,
params: SetLockedProductRedeemOptionParams,
) -> Result<RestApiResponse<SetLockedProductRedeemOptionResponse>>
pub async fn set_locked_product_redeem_option( &self, params: SetLockedProductRedeemOptionParams, ) -> Result<RestApiResponse<SetLockedProductRedeemOptionResponse>>
Set Locked Product Redeem Option(USER_DATA)
Set redeem option for Locked product
Weight: 50
Arguments
params:SetLockedProductRedeemOptionParamsThe parameters for this operation.
Returns
RestApiResponse<models::SetLockedProductRedeemOptionResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn simple_account(
&self,
params: SimpleAccountParams,
) -> Result<RestApiResponse<SimpleAccountResponse>>
pub async fn simple_account( &self, params: SimpleAccountParams, ) -> Result<RestApiResponse<SimpleAccountResponse>>
Simple Account(USER_DATA)
Simple Account query
Weight: 150
Arguments
params:SimpleAccountParamsThe parameters for this operation.
Returns
RestApiResponse<models::SimpleAccountResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn subscribe_flexible_product(
&self,
params: SubscribeFlexibleProductParams,
) -> Result<RestApiResponse<SubscribeFlexibleProductResponse>>
pub async fn subscribe_flexible_product( &self, params: SubscribeFlexibleProductParams, ) -> Result<RestApiResponse<SubscribeFlexibleProductResponse>>
Subscribe Flexible Product(TRADE)
Subscribe Flexible Product
- You need to open
Enable Spot & Margin Tradingpermission for the API Key which requests this endpoint.
Weight: 1
Arguments
params:SubscribeFlexibleProductParamsThe parameters for this operation.
Returns
RestApiResponse<models::SubscribeFlexibleProductResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn subscribe_locked_product(
&self,
params: SubscribeLockedProductParams,
) -> Result<RestApiResponse<SubscribeLockedProductResponse>>
pub async fn subscribe_locked_product( &self, params: SubscribeLockedProductParams, ) -> Result<RestApiResponse<SubscribeLockedProductResponse>>
Subscribe Locked Product(TRADE)
Subscribe Locked Product
- You need to open
Enable Spot & Margin Tradingpermission for the API Key which requests this endpoint.
Weight: 1
Arguments
params:SubscribeLockedProductParamsThe parameters for this operation.
Returns
RestApiResponse<models::SubscribeLockedProductResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_rwusd_account(
&self,
params: GetRwusdAccountParams,
) -> Result<RestApiResponse<GetRwusdAccountResponse>>
pub async fn get_rwusd_account( &self, params: GetRwusdAccountParams, ) -> Result<RestApiResponse<GetRwusdAccountResponse>>
Get RWUSD Account (USER_DATA)
Get RWUSD account information.
Weight: 150
Arguments
params:GetRwusdAccountParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetRwusdAccountResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_rwusd_quota_details(
&self,
params: GetRwusdQuotaDetailsParams,
) -> Result<RestApiResponse<GetRwusdQuotaDetailsResponse>>
pub async fn get_rwusd_quota_details( &self, params: GetRwusdQuotaDetailsParams, ) -> Result<RestApiResponse<GetRwusdQuotaDetailsResponse>>
Get RWUSD Quota Details (USER_DATA)
Get RWUSD quota details including subscription quota, fast redemption quota, and standard redemption quota.
Weight: 150
Arguments
params:GetRwusdQuotaDetailsParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetRwusdQuotaDetailsResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_rwusd_rate_history(
&self,
params: GetRwusdRateHistoryParams,
) -> Result<RestApiResponse<GetRwusdRateHistoryResponse>>
pub async fn get_rwusd_rate_history( &self, params: GetRwusdRateHistoryParams, ) -> Result<RestApiResponse<GetRwusdRateHistoryResponse>>
Get RWUSD Rate History (USER_DATA)
Get RWUSD rate history sorted by descending order.
- The time between
startTimeandendTimecannot be longer than 6 months. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent,endTimewill default to current time, and results fromstartTimeonward will be returned. - If
endTimeis sent butstartTimeis not sent,startTimedefaults to the current time minus one month, and data betweenstartTimeandendTimewill be returned.
Weight: 150
Arguments
params:GetRwusdRateHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetRwusdRateHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_rwusd_redemption_history(
&self,
params: GetRwusdRedemptionHistoryParams,
) -> Result<RestApiResponse<GetRwusdRedemptionHistoryResponse>>
pub async fn get_rwusd_redemption_history( &self, params: GetRwusdRedemptionHistoryParams, ) -> Result<RestApiResponse<GetRwusdRedemptionHistoryResponse>>
Get RWUSD Redemption History (USER_DATA)
Get RWUSD redemption history.
- The time between
startTimeandendTimecannot be longer than 6 months. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent,endTimewill default to current time, and results fromstartTimeonward will be returned. - If
endTimeis sent butstartTimeis not sent,startTimedefaults to the current time minus one month, and data betweenstartTimeandendTimewill be returned.
Weight: 150
Arguments
params:GetRwusdRedemptionHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetRwusdRedemptionHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_rwusd_rewards_history(
&self,
params: GetRwusdRewardsHistoryParams,
) -> Result<RestApiResponse<GetRwusdRewardsHistoryResponse>>
pub async fn get_rwusd_rewards_history( &self, params: GetRwusdRewardsHistoryParams, ) -> Result<RestApiResponse<GetRwusdRewardsHistoryResponse>>
Get RWUSD Rewards History (USER_DATA)
Get RWUSD rewards history.
- The time between
startTimeandendTimecannot be longer than 6 months. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent,endTimewill default to current time, and results fromstartTimeonward will be returned. - If
endTimeis sent butstartTimeis not sent,startTimedefaults to the current time minus one month, and data betweenstartTimeandendTimewill be returned.
Weight: 150
Arguments
params:GetRwusdRewardsHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetRwusdRewardsHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_rwusd_subscription_history(
&self,
params: GetRwusdSubscriptionHistoryParams,
) -> Result<RestApiResponse<GetRwusdSubscriptionHistoryResponse>>
pub async fn get_rwusd_subscription_history( &self, params: GetRwusdSubscriptionHistoryParams, ) -> Result<RestApiResponse<GetRwusdSubscriptionHistoryResponse>>
Get RWUSD subscription history(USER_DATA)
Get RWUSD subscription history
- The time between
startTimeandendTimecannot be longer than 6 months. - If
startTimeandendTimeare both not sent, then the last 30 days’ data will be returned. - If
startTimeis sent butendTimeis not sent,endTimewill default to current time, and results fromstartTimeonward will be returned. - If
endTimeis sent butstartTimeis not sent,startTimedefaults to the current time advanced by one month, and data betweenstartTimeandendTimewill be returned.
Weight: 150
Arguments
params:GetRwusdSubscriptionHistoryParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetRwusdSubscriptionHistoryResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn redeem_rwusd(
&self,
params: RedeemRwusdParams,
) -> Result<RestApiResponse<RedeemRwusdResponse>>
pub async fn redeem_rwusd( &self, params: RedeemRwusdParams, ) -> Result<RestApiResponse<RedeemRwusdResponse>>
Redeem RWUSD(TRADE)
Redeem RWUSD to USDC
- You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.
Weight: 150
Arguments
params:RedeemRwusdParamsThe parameters for this operation.
Returns
RestApiResponse<models::RedeemRwusdResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn subscribe_rwusd(
&self,
params: SubscribeRwusdParams,
) -> Result<RestApiResponse<SubscribeRwusdResponse>>
pub async fn subscribe_rwusd( &self, params: SubscribeRwusdParams, ) -> Result<RestApiResponse<SubscribeRwusdResponse>>
Subscribe RWUSD(TRADE)
Subscribe RWUSD
- You need to open Enable Spot & Margin Trading permission for the API Key which requests this endpoint.
Weight: 150
Arguments
params:SubscribeRwusdParamsThe parameters for this operation.
Returns
RestApiResponse<models::SubscribeRwusdResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.
Sourcepub async fn get_yield_arena_activities(
&self,
params: GetYieldArenaActivitiesParams,
) -> Result<RestApiResponse<GetYieldArenaActivitiesResponse>>
pub async fn get_yield_arena_activities( &self, params: GetYieldArenaActivitiesParams, ) -> Result<RestApiResponse<GetYieldArenaActivitiesResponse>>
Get Yield Arena Activities (USER_DATA)
Get the list of Earn Yield Arena giveaway activities currently available to the user.
Supported locales: en, en-GB, en-AU, cn, zh, zh-CN, tw, zh-TW, zh-HK, ja, ja-JP, ru, ru-RU, es, es-ES, es-LA, pt, pt-BR, pt-PT, fr, fr-FR, de, de-DE, it, it-IT, id, id-ID, vi, vi-VN, ar, ar-SA, pl, pl-PL, uk, uk-UA, cs, cs-CZ, ro, ro-RO, sv, sv-SE, bg, bg-BG, da, da-DK, el, el-GR, hu, hu-HU, lv, lv-LV, sk, sk-SK, sl, sl-SI.
Weight: 150
Arguments
params:GetYieldArenaActivitiesParamsThe parameters for this operation.
Returns
RestApiResponse<models::GetYieldArenaActivitiesResponse> on success.
Errors
This function will return an anyhow::Error if:
- the HTTP request fails
- any parameter is invalid
- the response cannot be parsed
- or one of the following occurs:
RequiredErrorConnectorClientErrorUnauthorizedErrorForbiddenErrorTooManyRequestsErrorRateLimitBanErrorServerErrorNotFoundErrorNetworkErrorBadRequestError
For full API details, see the Binance API Documentation.