pub struct AllOrderListParams {
pub from_id: Option<i64>,
pub start_time: Option<i64>,
pub end_time: Option<i64>,
pub limit: Option<i32>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [all_order_list] operation.
This struct holds all of the inputs you can pass when calling
all_order_list.
Fields
from_id: Option<i64>If supplied, neither startTime or endTime can be provided
This field is **optional.
start_time: Option<i64>The start_time parameter.
This field is **optional.
end_time: Option<i64>The end_time parameter.
This field is **optional.
limit: Option<i32>The limit parameter.
This field is **optional.
recv_window: Option<Decimal>Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl AllOrderListParams
impl AllOrderListParams
Sourcepub fn builder() -> AllOrderListParamsBuilder
pub fn builder() -> AllOrderListParamsBuilder
Create a builder for [all_order_list].