pub struct DeleteOrderListParams {
pub symbol: String,
pub order_list_id: Option<i64>,
pub list_client_order_id: Option<String>,
pub new_client_order_id: Option<String>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [delete_order_list] operation.
This struct holds all of the inputs you can pass when calling
delete_order_list.
Fields
symbol: StringThe symbol parameter.
This field is **required.
order_list_id: Option<i64>Either orderListId or listClientOrderId must be provided
This field is **optional.
list_client_order_id: Option<String>Either orderListId or listClientOrderId must be provided
This field is **optional.
new_client_order_id: Option<String>Used to uniquely identify this cancel. Automatically generated by default.
This field is **optional.
recv_window: Option<Decimal>Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl DeleteOrderListParams
impl DeleteOrderListParams
Sourcepub fn builder(symbol: String) -> DeleteOrderListParamsBuilder
pub fn builder(symbol: String) -> DeleteOrderListParamsBuilder
Create a builder for [delete_order_list].
Required parameters:
symbol— String