pub struct GetAccountParams {
pub omit_zero_balances: Option<bool>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [get_account] operation.
This struct holds all of the inputs you can pass when calling
get_account.
Fields
omit_zero_balances: Option<bool>When set to true, emits only the non-zero balances of an account.
This field is **optional.
recv_window: Option<Decimal>Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl GetAccountParams
impl GetAccountParams
Sourcepub fn builder() -> GetAccountParamsBuilder
pub fn builder() -> GetAccountParamsBuilder
Create a builder for [get_account].