OrderListOpocoParams

Struct OrderListOpocoParams 

pub struct OrderListOpocoParams {
Show 42 fields pub symbol: String, pub working_type: OrderListOpocoWorkingTypeEnum, pub working_side: OrderListOpocoWorkingSideEnum, pub working_price: Decimal, pub working_quantity: Decimal, pub pending_side: OrderListOpocoPendingSideEnum, pub pending_above_type: OrderListOpocoPendingAboveTypeEnum, pub list_client_order_id: Option<String>, pub new_order_resp_type: Option<OrderListOpocoNewOrderRespTypeEnum>, pub self_trade_prevention_mode: Option<OrderListOpocoSelfTradePreventionModeEnum>, pub working_client_order_id: Option<String>, pub working_iceberg_qty: Option<Decimal>, pub working_time_in_force: Option<OrderListOpocoWorkingTimeInForceEnum>, pub working_strategy_id: Option<i64>, pub working_strategy_type: Option<i32>, pub working_peg_price_type: Option<OrderListOpocoWorkingPegPriceTypeEnum>, pub working_peg_offset_type: Option<OrderListOpocoWorkingPegOffsetTypeEnum>, pub working_peg_offset_value: Option<i32>, pub pending_above_client_order_id: Option<String>, pub pending_above_price: Option<Decimal>, pub pending_above_stop_price: Option<Decimal>, pub pending_above_trailing_delta: Option<Decimal>, pub pending_above_iceberg_qty: Option<Decimal>, pub pending_above_time_in_force: Option<OrderListOpocoPendingAboveTimeInForceEnum>, pub pending_above_strategy_id: Option<i64>, pub pending_above_strategy_type: Option<i32>, pub pending_above_peg_price_type: Option<OrderListOpocoPendingAbovePegPriceTypeEnum>, pub pending_above_peg_offset_type: Option<OrderListOpocoPendingAbovePegOffsetTypeEnum>, pub pending_above_peg_offset_value: Option<i32>, pub pending_below_type: Option<OrderListOpocoPendingBelowTypeEnum>, pub pending_below_client_order_id: Option<String>, pub pending_below_price: Option<Decimal>, pub pending_below_stop_price: Option<Decimal>, pub pending_below_trailing_delta: Option<Decimal>, pub pending_below_iceberg_qty: Option<Decimal>, pub pending_below_time_in_force: Option<OrderListOpocoPendingBelowTimeInForceEnum>, pub pending_below_strategy_id: Option<i64>, pub pending_below_strategy_type: Option<i32>, pub pending_below_peg_price_type: Option<OrderListOpocoPendingBelowPegPriceTypeEnum>, pub pending_below_peg_offset_type: Option<OrderListOpocoPendingBelowPegOffsetTypeEnum>, pub pending_below_peg_offset_value: Option<i32>, pub recv_window: Option<Decimal>,
}
Request parameters for the [order_list_opoco] operation.

This struct holds all of the inputs you can pass when calling order_list_opoco.

Fields

symbol: String

The symbol parameter.

This field is **required.

working_type: OrderListOpocoWorkingTypeEnum

The working_type parameter.

This field is **required.

working_side: OrderListOpocoWorkingSideEnum

Supported values: Order Side

This field is **required.

working_price: Decimal

Price for the working order.

This field is **required.

working_quantity: Decimal

Sets the quantity for the working order.

This field is **required.

pending_side: OrderListOpocoPendingSideEnum

Supported values: Order Side

This field is **required.

pending_above_type: OrderListOpocoPendingAboveTypeEnum

Supported values: STOP_LOSS_LIMIT, STOP_LOSS, LIMIT_MAKER, TAKE_PROFIT, TAKE_PROFIT_LIMIT

This field is **required.

list_client_order_id: Option<String>

Arbitrary unique ID among open order lists. Automatically generated if not sent. A new order list with the same listClientOrderId is accepted only when the previous one is filled or completely expired. listClientOrderId is distinct from the workingClientOrderId and the pendingClientOrderId.

This field is **optional.

new_order_resp_type: Option<OrderListOpocoNewOrderRespTypeEnum>

Format of the JSON response. Supported values: Order Response Type

This field is **optional.

self_trade_prevention_mode: Option<OrderListOpocoSelfTradePreventionModeEnum>

The allowed enums is dependent on what is configured on the symbol. Supported values: STP Modes

This field is **optional.

working_client_order_id: Option<String>

Arbitrary unique ID among open orders for the working order. Automatically generated if not sent.

This field is **optional.

working_iceberg_qty: Option<Decimal>

This can only be used if workingTimeInForce is GTC, or if workingType is LIMIT_MAKER.

This field is **optional.

working_time_in_force: Option<OrderListOpocoWorkingTimeInForceEnum>

Supported values: Time In Force

This field is **optional.

working_strategy_id: Option<i64>

Arbitrary numeric value identifying the working order within an order strategy.

This field is **optional.

working_strategy_type: Option<i32>

Arbitrary numeric value identifying the working order strategy. Values smaller than 1000000 are reserved and cannot be used.

This field is **optional.

working_peg_price_type: Option<OrderListOpocoWorkingPegPriceTypeEnum>

See Pegged Orders

This field is **optional.

working_peg_offset_type: Option<OrderListOpocoWorkingPegOffsetTypeEnum>

See Pegged Orders

This field is **optional.

working_peg_offset_value: Option<i32>

Price level for pegging (max: 100). See Pegged Orders

This field is **optional.

pending_above_client_order_id: Option<String>

Arbitrary unique ID among open orders for the pending above order. Automatically generated if not sent.

This field is **optional.

pending_above_price: Option<Decimal>

Can be used if pendingAboveType is STOP_LOSS_LIMIT, LIMIT_MAKER, or TAKE_PROFIT_LIMIT to specify the limit price.

This field is **optional.

pending_above_stop_price: Option<Decimal>

Can be used if pendingAboveType is STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, TAKE_PROFIT_LIMIT.

This field is **optional.

pending_above_trailing_delta: Option<Decimal>

See Trailing Stop order FAQ

This field is **optional.

pending_above_iceberg_qty: Option<Decimal>

This can only be used if pendingAboveTimeInForce is GTC or pendingAboveType is LIMIT_MAKER.

This field is **optional.

pending_above_time_in_force: Option<OrderListOpocoPendingAboveTimeInForceEnum>

Required if pendingAboveType is STOP_LOSS_LIMIT or TAKE_PROFIT_LIMIT.

This field is **optional.

pending_above_strategy_id: Option<i64>

Arbitrary numeric value identifying the pending above order within an order strategy.

This field is **optional.

pending_above_strategy_type: Option<i32>

Arbitrary numeric value identifying the pending above order strategy. Values smaller than 1000000 are reserved and cannot be used.

This field is **optional.

pending_above_peg_price_type: Option<OrderListOpocoPendingAbovePegPriceTypeEnum>

See Pegged Orders

This field is **optional.

pending_above_peg_offset_type: Option<OrderListOpocoPendingAbovePegOffsetTypeEnum>

See Pegged Orders

This field is **optional.

pending_above_peg_offset_value: Option<i32>

Price level for pegging (max: 100). See Pegged Orders

This field is **optional.

pending_below_type: Option<OrderListOpocoPendingBelowTypeEnum>

Supported values: STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, TAKE_PROFIT_LIMIT

This field is **optional.

pending_below_client_order_id: Option<String>

Arbitrary unique ID among open orders for the pending below order. Automatically generated if not sent.

This field is **optional.

pending_below_price: Option<Decimal>

Can be used if pendingBelowType is STOP_LOSS_LIMIT or TAKE_PROFIT_LIMIT to specify the limit price.

This field is **optional.

pending_below_stop_price: Option<Decimal>

Can be used if pendingBelowType is STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, TAKE_PROFIT_LIMIT. Either pendingBelowStopPrice or pendingBelowTrailingDelta or both, must be specified.

This field is **optional.

pending_below_trailing_delta: Option<Decimal>

See Trailing Stop order FAQ

This field is **optional.

pending_below_iceberg_qty: Option<Decimal>

This can only be used if pendingBelowTimeInForce is GTC or pendingBelowType is LIMIT_MAKER.

This field is **optional.

pending_below_time_in_force: Option<OrderListOpocoPendingBelowTimeInForceEnum>

Supported values: Time In Force

This field is **optional.

pending_below_strategy_id: Option<i64>

Arbitrary numeric value identifying the pending below order within an order strategy.

This field is **optional.

pending_below_strategy_type: Option<i32>

Arbitrary numeric value identifying the pending below order strategy. Values smaller than 1000000 are reserved and cannot be used.

This field is **optional.

pending_below_peg_price_type: Option<OrderListOpocoPendingBelowPegPriceTypeEnum>

See Pegged Orders

This field is **optional.

pending_below_peg_offset_type: Option<OrderListOpocoPendingBelowPegOffsetTypeEnum>

The pending_below_peg_offset_type parameter.

This field is **optional.

pending_below_peg_offset_value: Option<i32>

The pending_below_peg_offset_value parameter.

This field is **optional.

recv_window: Option<Decimal>

The value cannot be greater than 60000. Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.

This field is **optional.

Implementations

Source

impl OrderListOpocoParams

pub fn builder( symbol: String, working_type: OrderListOpocoWorkingTypeEnum, working_side: OrderListOpocoWorkingSideEnum, working_price: Decimal, working_quantity: Decimal, pending_side: OrderListOpocoPendingSideEnum, pending_above_type: OrderListOpocoPendingAboveTypeEnum, ) -> OrderListOpocoParamsBuilder

Create a builder for [order_list_opoco].

Required parameters:

  • symbol — String
  • working_type — String
  • working_side — Supported values: Order Side
  • working_price — Price for the working order.
  • working_quantity — Sets the quantity for the working order.
  • pending_side — Supported values: Order Side
  • pending_above_type — Supported values: STOP_LOSS_LIMIT, STOP_LOSS, LIMIT_MAKER, TAKE_PROFIT, TAKE_PROFIT_LIMIT