pub struct OrderListOtocoParams {Show 43 fields
pub symbol: String,
pub working_type: OrderListOtocoWorkingTypeEnum,
pub working_side: OrderListOtocoWorkingSideEnum,
pub working_price: Decimal,
pub working_quantity: Decimal,
pub pending_side: OrderListOtocoPendingSideEnum,
pub pending_quantity: Decimal,
pub pending_above_type: OrderListOtocoPendingAboveTypeEnum,
pub list_client_order_id: Option<String>,
pub new_order_resp_type: Option<OrderListOtocoNewOrderRespTypeEnum>,
pub self_trade_prevention_mode: Option<OrderListOtocoSelfTradePreventionModeEnum>,
pub working_client_order_id: Option<String>,
pub working_iceberg_qty: Option<Decimal>,
pub working_time_in_force: Option<OrderListOtocoWorkingTimeInForceEnum>,
pub working_strategy_id: Option<i64>,
pub working_strategy_type: Option<i32>,
pub working_peg_price_type: Option<OrderListOtocoWorkingPegPriceTypeEnum>,
pub working_peg_offset_type: Option<OrderListOtocoWorkingPegOffsetTypeEnum>,
pub working_peg_offset_value: Option<i32>,
pub pending_above_client_order_id: Option<String>,
pub pending_above_price: Option<Decimal>,
pub pending_above_stop_price: Option<Decimal>,
pub pending_above_trailing_delta: Option<Decimal>,
pub pending_above_iceberg_qty: Option<Decimal>,
pub pending_above_time_in_force: Option<OrderListOtocoPendingAboveTimeInForceEnum>,
pub pending_above_strategy_id: Option<i64>,
pub pending_above_strategy_type: Option<i32>,
pub pending_above_peg_price_type: Option<OrderListOtocoPendingAbovePegPriceTypeEnum>,
pub pending_above_peg_offset_type: Option<OrderListOtocoPendingAbovePegOffsetTypeEnum>,
pub pending_above_peg_offset_value: Option<i32>,
pub pending_below_type: Option<OrderListOtocoPendingBelowTypeEnum>,
pub pending_below_client_order_id: Option<String>,
pub pending_below_price: Option<Decimal>,
pub pending_below_stop_price: Option<Decimal>,
pub pending_below_trailing_delta: Option<Decimal>,
pub pending_below_iceberg_qty: Option<Decimal>,
pub pending_below_time_in_force: Option<OrderListOtocoPendingBelowTimeInForceEnum>,
pub pending_below_strategy_id: Option<i64>,
pub pending_below_strategy_type: Option<i32>,
pub pending_below_peg_price_type: Option<OrderListOtocoPendingBelowPegPriceTypeEnum>,
pub pending_below_peg_offset_type: Option<OrderListOtocoPendingBelowPegOffsetTypeEnum>,
pub pending_below_peg_offset_value: Option<i32>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [order_list_otoco] operation.
This struct holds all of the inputs you can pass when calling
order_list_otoco.
Fields
symbol: StringThe symbol parameter.
This field is **required.
working_type: OrderListOtocoWorkingTypeEnumThe working_type parameter.
This field is **required.
working_side: OrderListOtocoWorkingSideEnumThe working_side parameter.
This field is **required.
working_price: DecimalThe working_price parameter.
This field is **required.
working_quantity: DecimalSets the quantity for the working order.
This field is **required.
pending_side: OrderListOtocoPendingSideEnumThe pending_side parameter.
This field is **required.
pending_quantity: DecimalSets the quantity for the pending order.
This field is **required.
pending_above_type: OrderListOtocoPendingAboveTypeEnumThe pending_above_type parameter.
This field is **required.
list_client_order_id: Option<String>A unique Id for the entire orderList
This field is **optional.
new_order_resp_type: Option<OrderListOtocoNewOrderRespTypeEnum>The new_order_resp_type parameter.
This field is **optional.
self_trade_prevention_mode: Option<OrderListOtocoSelfTradePreventionModeEnum>The self_trade_prevention_mode parameter.
This field is **optional.
working_client_order_id: Option<String>Arbitrary unique ID among open orders for the working order. Automatically generated if not sent.
This field is **optional.
working_iceberg_qty: Option<Decimal>This can only be used if workingTimeInForce is GTC, or if workingType is LIMIT_MAKER.
This field is **optional.
working_time_in_force: Option<OrderListOtocoWorkingTimeInForceEnum>The working_time_in_force parameter.
This field is **optional.
working_strategy_id: Option<i64>Arbitrary numeric value identifying the working order within an order strategy.
This field is **optional.
working_strategy_type: Option<i32>Arbitrary numeric value identifying the working order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
working_peg_price_type: Option<OrderListOtocoWorkingPegPriceTypeEnum>The working_peg_price_type parameter.
This field is **optional.
working_peg_offset_type: Option<OrderListOtocoWorkingPegOffsetTypeEnum>The working_peg_offset_type parameter.
This field is **optional.
working_peg_offset_value: Option<i32>The working_peg_offset_value parameter.
This field is **optional.
pending_above_client_order_id: Option<String>Arbitrary unique ID among open orders for the pending above order. Automatically generated if not sent.
This field is **optional.
pending_above_price: Option<Decimal>Can be used if pendingAboveType is STOP_LOSS_LIMIT , LIMIT_MAKER, or TAKE_PROFIT_LIMIT to specify the limit price.
This field is **optional.
pending_above_stop_price: Option<Decimal>Can be used if pendingAboveType is STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, TAKE_PROFIT_LIMIT
This field is **optional.
pending_above_trailing_delta: Option<Decimal>This field is **optional.
pending_above_iceberg_qty: Option<Decimal>This can only be used if pendingAboveTimeInForce is GTC or if pendingAboveType is LIMIT_MAKER.
This field is **optional.
pending_above_time_in_force: Option<OrderListOtocoPendingAboveTimeInForceEnum>The pending_above_time_in_force parameter.
This field is **optional.
pending_above_strategy_id: Option<i64>Arbitrary numeric value identifying the pending above order within an order strategy.
This field is **optional.
pending_above_strategy_type: Option<i32>Arbitrary numeric value identifying the pending above order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
pending_above_peg_price_type: Option<OrderListOtocoPendingAbovePegPriceTypeEnum>The pending_above_peg_price_type parameter.
This field is **optional.
pending_above_peg_offset_type: Option<OrderListOtocoPendingAbovePegOffsetTypeEnum>The pending_above_peg_offset_type parameter.
This field is **optional.
pending_above_peg_offset_value: Option<i32>The pending_above_peg_offset_value parameter.
This field is **optional.
pending_below_type: Option<OrderListOtocoPendingBelowTypeEnum>The pending_below_type parameter.
This field is **optional.
pending_below_client_order_id: Option<String>Arbitrary unique ID among open orders for the pending below order. Automatically generated if not sent.
This field is **optional.
pending_below_price: Option<Decimal>Can be used if pendingBelowType is STOP_LOSS_LIMIT or TAKE_PROFIT_LIMIT to specify limit price
This field is **optional.
pending_below_stop_price: Option<Decimal>Can be used if pendingBelowType is STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT or TAKE_PROFIT_LIMIT. Either pendingBelowStopPrice or pendingBelowTrailingDelta or both, must be specified.
This field is **optional.
pending_below_trailing_delta: Option<Decimal>The pending_below_trailing_delta parameter.
This field is **optional.
pending_below_iceberg_qty: Option<Decimal>This can only be used if pendingBelowTimeInForce is GTC, or if pendingBelowType is LIMIT_MAKER.
This field is **optional.
pending_below_time_in_force: Option<OrderListOtocoPendingBelowTimeInForceEnum>The pending_below_time_in_force parameter.
This field is **optional.
pending_below_strategy_id: Option<i64>Arbitrary numeric value identifying the pending below order within an order strategy.
This field is **optional.
pending_below_strategy_type: Option<i32>Arbitrary numeric value identifying the pending below order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
pending_below_peg_price_type: Option<OrderListOtocoPendingBelowPegPriceTypeEnum>The pending_below_peg_price_type parameter.
This field is **optional.
pending_below_peg_offset_type: Option<OrderListOtocoPendingBelowPegOffsetTypeEnum>The pending_below_peg_offset_type parameter.
This field is **optional.
pending_below_peg_offset_value: Option<i32>The pending_below_peg_offset_value parameter.
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OrderListOtocoParams
impl OrderListOtocoParams
Sourcepub fn builder(
symbol: String,
working_type: OrderListOtocoWorkingTypeEnum,
working_side: OrderListOtocoWorkingSideEnum,
working_price: Decimal,
working_quantity: Decimal,
pending_side: OrderListOtocoPendingSideEnum,
pending_quantity: Decimal,
pending_above_type: OrderListOtocoPendingAboveTypeEnum,
) -> OrderListOtocoParamsBuilder
pub fn builder( symbol: String, working_type: OrderListOtocoWorkingTypeEnum, working_side: OrderListOtocoWorkingSideEnum, working_price: Decimal, working_quantity: Decimal, pending_side: OrderListOtocoPendingSideEnum, pending_quantity: Decimal, pending_above_type: OrderListOtocoPendingAboveTypeEnum, ) -> OrderListOtocoParamsBuilder
Create a builder for [order_list_otoco].
Required parameters:
symbol— Stringworking_type— Stringworking_side— Stringworking_price—rust_decimal::Decimalworking_quantity— Sets the quantity for the working order.pending_side— Stringpending_quantity— Sets the quantity for the pending order.pending_above_type— String