OrderTestParams

Struct OrderTestParams 

pub struct OrderTestParams {
Show 20 fields pub symbol: String, pub side: OrderTestSideEnum, pub type: OrderTestTypeEnum, pub compute_commission_rates: Option<bool>, pub time_in_force: Option<OrderTestTimeInForceEnum>, pub quantity: Option<Decimal>, pub quote_order_qty: Option<Decimal>, pub price: Option<Decimal>, pub new_client_order_id: Option<String>, pub strategy_id: Option<i64>, pub strategy_type: Option<i32>, pub stop_price: Option<Decimal>, pub trailing_delta: Option<i64>, pub iceberg_qty: Option<Decimal>, pub new_order_resp_type: Option<OrderTestNewOrderRespTypeEnum>, pub self_trade_prevention_mode: Option<OrderTestSelfTradePreventionModeEnum>, pub peg_price_type: Option<OrderTestPegPriceTypeEnum>, pub peg_offset_value: Option<i32>, pub peg_offset_type: Option<OrderTestPegOffsetTypeEnum>, pub recv_window: Option<Decimal>,
}
Request parameters for the [order_test] operation.

This struct holds all of the inputs you can pass when calling order_test.

Fields

symbol: String

The symbol parameter.

This field is **required.

side: OrderTestSideEnum

Please see Enums for supported values.

This field is **required.

type: OrderTestTypeEnum

Please see Enums for supported values.

This field is **required.

compute_commission_rates: Option<bool>

Default: false
See Commissions FAQ to learn more.

This field is **optional.

time_in_force: Option<OrderTestTimeInForceEnum>

Please see Enums for supported values.

This field is **optional.

quantity: Option<Decimal>

The quantity parameter.

This field is **optional.

quote_order_qty: Option<Decimal>

The quote_order_qty parameter.

This field is **optional.

price: Option<Decimal>

The price parameter.

This field is **optional.

new_client_order_id: Option<String>

A unique id among open orders. Automatically generated if not sent. Orders with the same newClientOrderID can be accepted only when the previous one is filled, otherwise the order will be rejected.

This field is **optional.

strategy_id: Option<i64>

The strategy_id parameter.

This field is **optional.

strategy_type: Option<i32>

The value cannot be less than 1000000.

This field is **optional.

stop_price: Option<Decimal>

Used with STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, and TAKE_PROFIT_LIMIT orders.

This field is **optional.

trailing_delta: Option<i64>

See Trailing Stop order FAQ

This field is **optional.

iceberg_qty: Option<Decimal>

Used with LIMIT, STOP_LOSS_LIMIT, and TAKE_PROFIT_LIMIT to create an iceberg order.

This field is **optional.

new_order_resp_type: Option<OrderTestNewOrderRespTypeEnum>

Set the response JSON. ACK, RESULT, or FULL; MARKET and LIMIT order types default to FULL, all other orders default to ACK.

This field is **optional.

self_trade_prevention_mode: Option<OrderTestSelfTradePreventionModeEnum>

The allowed enums is dependent on what is configured on the symbol. Supported values: STP Modes

This field is **optional.

peg_price_type: Option<OrderTestPegPriceTypeEnum>

PRIMARY_PEG or MARKET_PEG. See Pegged Orders

This field is **optional.

peg_offset_value: Option<i32>

Price level for pegging (max: 100). See Pegged Orders

This field is **optional.

peg_offset_type: Option<OrderTestPegOffsetTypeEnum>

Only PRICE_LEVEL is supported. See Pegged Orders

This field is **optional.

recv_window: Option<Decimal>

The value cannot be greater than 60000. Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.

This field is **optional.

Implementations

Source

impl OrderTestParams

pub fn builder( symbol: String, side: OrderTestSideEnum, type: OrderTestTypeEnum, ) -> OrderTestParamsBuilder

Create a builder for [order_test].

Required parameters:

  • symbol — String
  • side — Please see Enums for supported values.
  • r#type — Please see Enums for supported values.