pub struct OpenOrdersStatusParams {
pub id: Option<String>,
pub symbol: Option<String>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [open_orders_status] operation.
This struct holds all of the inputs you can pass when calling
open_orders_status.
Fields
id: Option<String>Client-generated request identifier.
This field is **optional.
symbol: Option<String>If omitted, open orders for all symbols are returned
This field is **optional.
recv_window: Option<Decimal>Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OpenOrdersStatusParams
impl OpenOrdersStatusParams
Sourcepub fn builder() -> OpenOrdersStatusParamsBuilder
pub fn builder() -> OpenOrdersStatusParamsBuilder
Create a builder for [open_orders_status].