pub struct OrderListCancelParams {
pub symbol: String,
pub id: Option<String>,
pub order_list_id: Option<i32>,
pub list_client_order_id: Option<String>,
pub new_client_order_id: Option<String>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [order_list_cancel] operation.
This struct holds all of the inputs you can pass when calling
order_list_cancel.
Fields
symbol: StringThe symbol parameter.
This field is **required.
id: Option<String>Client-generated request identifier.
This field is **optional.
order_list_id: Option<i32>Either orderListId or listClientOrderId must be provided
This field is **optional.
list_client_order_id: Option<String>Either orderListId or listClientOrderId must be provided
This field is **optional.
new_client_order_id: Option<String>Used to uniquely identify this cancel. Automatically generated by default.
This field is **optional.
recv_window: Option<Decimal>Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OrderListCancelParams
impl OrderListCancelParams
Sourcepub fn builder(symbol: String) -> OrderListCancelParamsBuilder
pub fn builder(symbol: String) -> OrderListCancelParamsBuilder
Create a builder for [order_list_cancel].
Required parameters:
symbol— String