pub struct OrderListPlaceOcoParams {Show 32 fields
pub symbol: String,
pub side: OrderListPlaceOcoSideEnum,
pub quantity: Decimal,
pub above_type: OrderListPlaceOcoAboveTypeEnum,
pub below_type: OrderListPlaceOcoBelowTypeEnum,
pub id: Option<String>,
pub list_client_order_id: Option<String>,
pub above_client_order_id: Option<String>,
pub above_iceberg_qty: Option<i64>,
pub above_price: Option<Decimal>,
pub above_stop_price: Option<Decimal>,
pub above_trailing_delta: Option<i64>,
pub above_time_in_force: Option<OrderListPlaceOcoAboveTimeInForceEnum>,
pub above_strategy_id: Option<i64>,
pub above_strategy_type: Option<i32>,
pub above_peg_price_type: Option<OrderListPlaceOcoAbovePegPriceTypeEnum>,
pub above_peg_offset_type: Option<OrderListPlaceOcoAbovePegOffsetTypeEnum>,
pub above_peg_offset_value: Option<i32>,
pub below_client_order_id: Option<String>,
pub below_iceberg_qty: Option<i64>,
pub below_price: Option<Decimal>,
pub below_stop_price: Option<Decimal>,
pub below_trailing_delta: Option<i64>,
pub below_time_in_force: Option<OrderListPlaceOcoBelowTimeInForceEnum>,
pub below_strategy_id: Option<i64>,
pub below_strategy_type: Option<i32>,
pub below_peg_price_type: Option<OrderListPlaceOcoBelowPegPriceTypeEnum>,
pub below_peg_offset_type: Option<OrderListPlaceOcoBelowPegOffsetTypeEnum>,
pub below_peg_offset_value: Option<i32>,
pub new_order_resp_type: Option<OrderListPlaceOcoNewOrderRespTypeEnum>,
pub self_trade_prevention_mode: Option<OrderListPlaceOcoSelfTradePreventionModeEnum>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [order_list_place_oco] operation.
This struct holds all of the inputs you can pass when calling
order_list_place_oco.
Fields
symbol: StringThe symbol parameter.
This field is **required.
side: OrderListPlaceOcoSideEnumThe side parameter.
This field is **required.
quantity: DecimalThe quantity parameter.
This field is **required.
above_type: OrderListPlaceOcoAboveTypeEnumThe above_type parameter.
This field is **required.
below_type: OrderListPlaceOcoBelowTypeEnumThe below_type parameter.
This field is **required.
id: Option<String>Unique WebSocket request ID.
This field is **optional.
list_client_order_id: Option<String>The list_client_order_id parameter.
This field is **optional.
above_client_order_id: Option<String>Arbitrary unique ID among open orders for the above order. Automatically generated if not sent
This field is **optional.
above_iceberg_qty: Option<i64>Note that this can only be used if aboveTimeInForce is GTC.
This field is **optional.
above_price: Option<Decimal>Can be used if aboveType is STOP_LOSS_LIMIT , LIMIT_MAKER, or TAKE_PROFIT_LIMIT to specify the limit price.
This field is **optional.
above_stop_price: Option<Decimal>Can be used if aboveType is STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, TAKE_PROFIT_LIMIT.
Either aboveStopPrice or aboveTrailingDelta or both, must be specified.
This field is **optional.
above_trailing_delta: Option<i64>This field is **optional.
above_time_in_force: Option<OrderListPlaceOcoAboveTimeInForceEnum>The above_time_in_force parameter.
This field is **optional.
above_strategy_id: Option<i64>Arbitrary numeric value identifying the above order within an order strategy.
This field is **optional.
above_strategy_type: Option<i32>Arbitrary numeric value identifying the above order strategy.
Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
above_peg_price_type: Option<OrderListPlaceOcoAbovePegPriceTypeEnum>The above_peg_price_type parameter.
This field is **optional.
above_peg_offset_type: Option<OrderListPlaceOcoAbovePegOffsetTypeEnum>The above_peg_offset_type parameter.
This field is **optional.
above_peg_offset_value: Option<i32>The above_peg_offset_value parameter.
This field is **optional.
below_client_order_id: Option<String>The below_client_order_id parameter.
This field is **optional.
below_iceberg_qty: Option<i64>Note that this can only be used if belowTimeInForce is GTC.
This field is **optional.
below_price: Option<Decimal>Can be used if belowType is STOP_LOSS_LIMIT , LIMIT_MAKER, or TAKE_PROFIT_LIMIT to specify the limit price.
This field is **optional.
below_stop_price: Option<Decimal>Can be used if belowType is STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT or TAKE_PROFIT_LIMIT.
Either belowStopPrice or belowTrailingDelta or both, must be specified.
This field is **optional.
below_trailing_delta: Option<i64>This field is **optional.
below_time_in_force: Option<OrderListPlaceOcoBelowTimeInForceEnum>The below_time_in_force parameter.
This field is **optional.
below_strategy_id: Option<i64>Arbitrary numeric value identifying the below order within an order strategy.
This field is **optional.
below_strategy_type: Option<i32>Arbitrary numeric value identifying the below order strategy.
Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
below_peg_price_type: Option<OrderListPlaceOcoBelowPegPriceTypeEnum>The below_peg_price_type parameter.
This field is **optional.
below_peg_offset_type: Option<OrderListPlaceOcoBelowPegOffsetTypeEnum>The below_peg_offset_type parameter.
This field is **optional.
below_peg_offset_value: Option<i32>The below_peg_offset_value parameter.
This field is **optional.
new_order_resp_type: Option<OrderListPlaceOcoNewOrderRespTypeEnum>The new_order_resp_type parameter.
This field is **optional.
self_trade_prevention_mode: Option<OrderListPlaceOcoSelfTradePreventionModeEnum>The self_trade_prevention_mode parameter.
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OrderListPlaceOcoParams
impl OrderListPlaceOcoParams
Sourcepub fn builder(
symbol: String,
side: OrderListPlaceOcoSideEnum,
quantity: Decimal,
above_type: OrderListPlaceOcoAboveTypeEnum,
below_type: OrderListPlaceOcoBelowTypeEnum,
) -> OrderListPlaceOcoParamsBuilder
pub fn builder( symbol: String, side: OrderListPlaceOcoSideEnum, quantity: Decimal, above_type: OrderListPlaceOcoAboveTypeEnum, below_type: OrderListPlaceOcoBelowTypeEnum, ) -> OrderListPlaceOcoParamsBuilder
Create a builder for [order_list_place_oco].
Required parameters:
symbol— Stringside— Stringquantity—rust_decimal::Decimalabove_type— Stringbelow_type— String