pub struct OrderListPlaceOpocoParamsBuilder { /* private fields */ }Expand description
Builder for OrderListPlaceOpocoParams.
Implementations
Sourceimpl OrderListPlaceOpocoParamsBuilder
impl OrderListPlaceOpocoParamsBuilder
Sourcepub fn symbol<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn symbol<VALUE: Into<String>>(self, value: VALUE) -> Self
The symbol parameter.
This field is **required.
Sourcepub fn working_type<VALUE: Into<OrderListPlaceOpocoWorkingTypeEnum>>(
self,
value: VALUE,
) -> Self
pub fn working_type<VALUE: Into<OrderListPlaceOpocoWorkingTypeEnum>>( self, value: VALUE, ) -> Self
The working_type parameter.
This field is **required.
Sourcepub fn working_side<VALUE: Into<OrderListPlaceOpocoWorkingSideEnum>>(
self,
value: VALUE,
) -> Self
pub fn working_side<VALUE: Into<OrderListPlaceOpocoWorkingSideEnum>>( self, value: VALUE, ) -> Self
Supported values: Order Side
This field is **required.
Sourcepub fn working_price<VALUE: Into<Decimal>>(self, value: VALUE) -> Self
pub fn working_price<VALUE: Into<Decimal>>(self, value: VALUE) -> Self
Price for the working order.
This field is **required.
Sourcepub fn working_quantity<VALUE: Into<Decimal>>(self, value: VALUE) -> Self
pub fn working_quantity<VALUE: Into<Decimal>>(self, value: VALUE) -> Self
Sets the quantity for the working order.
This field is **required.
Sourcepub fn pending_side<VALUE: Into<OrderListPlaceOpocoPendingSideEnum>>(
self,
value: VALUE,
) -> Self
pub fn pending_side<VALUE: Into<OrderListPlaceOpocoPendingSideEnum>>( self, value: VALUE, ) -> Self
Supported values: Order Side
This field is **required.
Sourcepub fn pending_above_type<VALUE: Into<OrderListPlaceOpocoPendingAboveTypeEnum>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_type<VALUE: Into<OrderListPlaceOpocoPendingAboveTypeEnum>>( self, value: VALUE, ) -> Self
Supported values: STOP_LOSS_LIMIT, STOP_LOSS, LIMIT_MAKER, TAKE_PROFIT, TAKE_PROFIT_LIMIT
This field is **required.
Sourcepub fn id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
Client-generated request identifier.
This field is **optional.
Sourcepub fn list_client_order_id<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn list_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
Arbitrary unique ID among open order lists. Automatically generated if not sent. A new order list with the same listClientOrderId is accepted only when the previous one is filled or completely expired. listClientOrderId is distinct from the workingClientOrderId and the pendingClientOrderId.
This field is **optional.
Sourcepub fn new_order_resp_type<VALUE: Into<Option<OrderListPlaceOpocoNewOrderRespTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn new_order_resp_type<VALUE: Into<Option<OrderListPlaceOpocoNewOrderRespTypeEnum>>>( self, value: VALUE, ) -> Self
Format of the JSON response. Supported values: Order Response Type
This field is **optional.
Sourcepub fn self_trade_prevention_mode<VALUE: Into<Option<OrderListPlaceOpocoSelfTradePreventionModeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn self_trade_prevention_mode<VALUE: Into<Option<OrderListPlaceOpocoSelfTradePreventionModeEnum>>>( self, value: VALUE, ) -> Self
The allowed enums is dependent on what is configured on the symbol. Supported values: STP Modes
This field is **optional.
Sourcepub fn working_client_order_id<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn working_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
Arbitrary unique ID among open orders for the working order. Automatically generated if not sent.
This field is **optional.
Sourcepub fn working_iceberg_qty<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn working_iceberg_qty<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
This can only be used if workingTimeInForce is GTC, or if workingType is LIMIT_MAKER.
This field is **optional.
Sourcepub fn working_time_in_force<VALUE: Into<Option<OrderListPlaceOpocoWorkingTimeInForceEnum>>>(
self,
value: VALUE,
) -> Self
pub fn working_time_in_force<VALUE: Into<Option<OrderListPlaceOpocoWorkingTimeInForceEnum>>>( self, value: VALUE, ) -> Self
Supported values: Time In Force
This field is **optional.
Sourcepub fn working_strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
pub fn working_strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
Arbitrary numeric value identifying the working order within an order strategy.
This field is **optional.
Sourcepub fn working_strategy_type<VALUE: Into<Option<i32>>>(
self,
value: VALUE,
) -> Self
pub fn working_strategy_type<VALUE: Into<Option<i32>>>( self, value: VALUE, ) -> Self
Arbitrary numeric value identifying the working order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
Sourcepub fn working_peg_price_type<VALUE: Into<Option<OrderListPlaceOpocoWorkingPegPriceTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn working_peg_price_type<VALUE: Into<Option<OrderListPlaceOpocoWorkingPegPriceTypeEnum>>>( self, value: VALUE, ) -> Self
See Pegged Orders
This field is **optional.
Sourcepub fn working_peg_offset_type<VALUE: Into<Option<OrderListPlaceOpocoWorkingPegOffsetTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn working_peg_offset_type<VALUE: Into<Option<OrderListPlaceOpocoWorkingPegOffsetTypeEnum>>>( self, value: VALUE, ) -> Self
See Pegged Orders
This field is **optional.
Sourcepub fn working_peg_offset_value<VALUE: Into<Option<i32>>>(
self,
value: VALUE,
) -> Self
pub fn working_peg_offset_value<VALUE: Into<Option<i32>>>( self, value: VALUE, ) -> Self
Price level for pegging (max: 100). See Pegged Orders
This field is **optional.
Sourcepub fn pending_above_client_order_id<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
Arbitrary unique ID among open orders for the pending above order. Automatically generated if not sent.
This field is **optional.
Sourcepub fn pending_above_price<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_price<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
Can be used if pendingAboveType is STOP_LOSS_LIMIT, LIMIT_MAKER, or TAKE_PROFIT_LIMIT to specify the limit price.
This field is **optional.
Sourcepub fn pending_above_stop_price<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_stop_price<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
Can be used if pendingAboveType is STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, TAKE_PROFIT_LIMIT.
This field is **optional.
Sourcepub fn pending_above_trailing_delta<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_trailing_delta<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
This field is **optional.
Sourcepub fn pending_above_iceberg_qty<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_iceberg_qty<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
This can only be used if pendingAboveTimeInForce is GTC or pendingAboveType is LIMIT_MAKER.
This field is **optional.
Sourcepub fn pending_above_time_in_force<VALUE: Into<Option<OrderListPlaceOpocoPendingAboveTimeInForceEnum>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_time_in_force<VALUE: Into<Option<OrderListPlaceOpocoPendingAboveTimeInForceEnum>>>( self, value: VALUE, ) -> Self
Required if pendingAboveType is STOP_LOSS_LIMIT or TAKE_PROFIT_LIMIT.
This field is **optional.
Sourcepub fn pending_above_strategy_id<VALUE: Into<Option<i64>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_strategy_id<VALUE: Into<Option<i64>>>( self, value: VALUE, ) -> Self
Arbitrary numeric value identifying the pending above order within an order strategy.
This field is **optional.
Sourcepub fn pending_above_strategy_type<VALUE: Into<Option<i32>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_strategy_type<VALUE: Into<Option<i32>>>( self, value: VALUE, ) -> Self
Arbitrary numeric value identifying the pending above order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
Sourcepub fn pending_above_peg_price_type<VALUE: Into<Option<OrderListPlaceOpocoPendingAbovePegPriceTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_peg_price_type<VALUE: Into<Option<OrderListPlaceOpocoPendingAbovePegPriceTypeEnum>>>( self, value: VALUE, ) -> Self
See Pegged Orders
This field is **optional.
Sourcepub fn pending_above_peg_offset_type<VALUE: Into<Option<OrderListPlaceOpocoPendingAbovePegOffsetTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_peg_offset_type<VALUE: Into<Option<OrderListPlaceOpocoPendingAbovePegOffsetTypeEnum>>>( self, value: VALUE, ) -> Self
See Pegged Orders
This field is **optional.
Sourcepub fn pending_above_peg_offset_value<VALUE: Into<Option<i32>>>(
self,
value: VALUE,
) -> Self
pub fn pending_above_peg_offset_value<VALUE: Into<Option<i32>>>( self, value: VALUE, ) -> Self
Price level for pegging (max: 100). See Pegged Orders
This field is **optional.
Sourcepub fn pending_below_type<VALUE: Into<Option<OrderListPlaceOpocoPendingBelowTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_type<VALUE: Into<Option<OrderListPlaceOpocoPendingBelowTypeEnum>>>( self, value: VALUE, ) -> Self
Supported values: STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, TAKE_PROFIT_LIMIT
This field is **optional.
Sourcepub fn pending_below_client_order_id<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
Arbitrary unique ID among open orders for the pending below order. Automatically generated if not sent.
This field is **optional.
Sourcepub fn pending_below_price<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_price<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
Can be used if pendingBelowType is STOP_LOSS_LIMIT or TAKE_PROFIT_LIMIT to specify the limit price.
This field is **optional.
Sourcepub fn pending_below_stop_price<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_stop_price<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
Can be used if pendingBelowType is STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, TAKE_PROFIT_LIMIT. Either pendingBelowStopPrice or pendingBelowTrailingDelta or both, must be specified.
This field is **optional.
Sourcepub fn pending_below_trailing_delta<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_trailing_delta<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
This field is **optional.
Sourcepub fn pending_below_iceberg_qty<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_iceberg_qty<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
This can only be used if pendingBelowTimeInForce is GTC or pendingBelowType is LIMIT_MAKER.
This field is **optional.
Sourcepub fn pending_below_time_in_force<VALUE: Into<Option<OrderListPlaceOpocoPendingBelowTimeInForceEnum>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_time_in_force<VALUE: Into<Option<OrderListPlaceOpocoPendingBelowTimeInForceEnum>>>( self, value: VALUE, ) -> Self
Supported values: Time In Force
This field is **optional.
Sourcepub fn pending_below_strategy_id<VALUE: Into<Option<i64>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_strategy_id<VALUE: Into<Option<i64>>>( self, value: VALUE, ) -> Self
Arbitrary numeric value identifying the pending below order within an order strategy.
This field is **optional.
Sourcepub fn pending_below_strategy_type<VALUE: Into<Option<i32>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_strategy_type<VALUE: Into<Option<i32>>>( self, value: VALUE, ) -> Self
Arbitrary numeric value identifying the pending below order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
Sourcepub fn pending_below_peg_price_type<VALUE: Into<Option<OrderListPlaceOpocoPendingBelowPegPriceTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_peg_price_type<VALUE: Into<Option<OrderListPlaceOpocoPendingBelowPegPriceTypeEnum>>>( self, value: VALUE, ) -> Self
See Pegged Orders
This field is **optional.
Sourcepub fn pending_below_peg_offset_type<VALUE: Into<Option<OrderListPlaceOpocoPendingBelowPegOffsetTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_peg_offset_type<VALUE: Into<Option<OrderListPlaceOpocoPendingBelowPegOffsetTypeEnum>>>( self, value: VALUE, ) -> Self
The pending_below_peg_offset_type parameter.
This field is **optional.
Sourcepub fn pending_below_peg_offset_value<VALUE: Into<Option<i32>>>(
self,
value: VALUE,
) -> Self
pub fn pending_below_peg_offset_value<VALUE: Into<Option<i32>>>( self, value: VALUE, ) -> Self
The pending_below_peg_offset_value parameter.
This field is **optional.
Sourcepub fn recv_window<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn recv_window<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.