pub struct OrderListPlaceParamsBuilder { /* private fields */ }Expand description
Builder for OrderListPlaceParams.
Implementations
Sourceimpl OrderListPlaceParamsBuilder
impl OrderListPlaceParamsBuilder
Sourcepub fn symbol<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn symbol<VALUE: Into<String>>(self, value: VALUE) -> Self
The symbol parameter.
This field is **required.
Sourcepub fn side<VALUE: Into<OrderListPlaceSideEnum>>(self, value: VALUE) -> Self
pub fn side<VALUE: Into<OrderListPlaceSideEnum>>(self, value: VALUE) -> Self
Please see Enums for supported values.
This field is **required.
Sourcepub fn price<VALUE: Into<Decimal>>(self, value: VALUE) -> Self
pub fn price<VALUE: Into<Decimal>>(self, value: VALUE) -> Self
The price parameter.
This field is **required.
Sourcepub fn quantity<VALUE: Into<Decimal>>(self, value: VALUE) -> Self
pub fn quantity<VALUE: Into<Decimal>>(self, value: VALUE) -> Self
The quantity parameter.
This field is **required.
Sourcepub fn id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
Client-generated request identifier.
This field is **optional.
Sourcepub fn list_client_order_id<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn list_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
A unique Id for the entire orderList
This field is **optional.
Sourcepub fn limit_client_order_id<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn limit_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
A unique Id for the limit order
This field is **optional.
Sourcepub fn limit_iceberg_qty<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn limit_iceberg_qty<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
Used to make the LIMIT_MAKER leg an iceberg order.
This field is **optional.
Sourcepub fn limit_strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
pub fn limit_strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
The limit_strategy_id parameter.
This field is **optional.
Sourcepub fn limit_strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
pub fn limit_strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
The value cannot be less than 1000000.
This field is **optional.
Sourcepub fn stop_price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn stop_price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
The stop_price parameter.
This field is **optional.
Sourcepub fn trailing_delta<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
pub fn trailing_delta<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
The trailing_delta parameter.
This field is **optional.
Sourcepub fn stop_client_order_id<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn stop_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
A unique Id for the stop loss/stop loss limit leg
This field is **optional.
Sourcepub fn stop_limit_price<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn stop_limit_price<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
If provided, stopLimitTimeInForce is required.
This field is **optional.
Sourcepub fn stop_limit_time_in_force<VALUE: Into<Option<OrderListPlaceStopLimitTimeInForceEnum>>>(
self,
value: VALUE,
) -> Self
pub fn stop_limit_time_in_force<VALUE: Into<Option<OrderListPlaceStopLimitTimeInForceEnum>>>( self, value: VALUE, ) -> Self
Valid values are GTC/FOK/IOC
This field is **optional.
Sourcepub fn stop_iceberg_qty<VALUE: Into<Option<Decimal>>>(
self,
value: VALUE,
) -> Self
pub fn stop_iceberg_qty<VALUE: Into<Option<Decimal>>>( self, value: VALUE, ) -> Self
Used with STOP_LOSS_LIMIT leg to make an iceberg order.
This field is **optional.
Sourcepub fn stop_strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
pub fn stop_strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
The stop_strategy_id parameter.
This field is **optional.
Sourcepub fn stop_strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
pub fn stop_strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
The value cannot be less than 1000000.
This field is **optional.
Sourcepub fn new_order_resp_type<VALUE: Into<Option<OrderListPlaceNewOrderRespTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn new_order_resp_type<VALUE: Into<Option<OrderListPlaceNewOrderRespTypeEnum>>>( self, value: VALUE, ) -> Self
Format of the JSON response. Supported values: Order Response Type
This field is **optional.
Sourcepub fn self_trade_prevention_mode<VALUE: Into<Option<OrderListPlaceSelfTradePreventionModeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn self_trade_prevention_mode<VALUE: Into<Option<OrderListPlaceSelfTradePreventionModeEnum>>>( self, value: VALUE, ) -> Self
The allowed values are dependent on what is configured on the symbol. Supported values: STP Modes
This field is **optional.
Sourcepub fn recv_window<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn recv_window<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.