pub struct OrderStatusParams {
pub symbol: String,
pub id: Option<String>,
pub order_id: Option<i64>,
pub orig_client_order_id: Option<String>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [order_status] operation.
This struct holds all of the inputs you can pass when calling
order_status.
Fields
symbol: StringThe symbol parameter.
This field is **required.
id: Option<String>Unique WebSocket request ID.
This field is **optional.
order_id: Option<i64>orderIdororigClientOrderIdmustbesent
This field is **optional.
orig_client_order_id: Option<String>orderIdororigClientOrderIdmustbesent
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl OrderStatusParams
impl OrderStatusParams
Sourcepub fn builder(symbol: String) -> OrderStatusParamsBuilder
pub fn builder(symbol: String) -> OrderStatusParamsBuilder
Create a builder for [order_status].
Required parameters:
symbol— String