pub struct SorOrderPlaceParams {Show 14 fields
pub symbol: String,
pub side: SorOrderPlaceSideEnum,
pub type: SorOrderPlaceTypeEnum,
pub quantity: Decimal,
pub id: Option<String>,
pub time_in_force: Option<SorOrderPlaceTimeInForceEnum>,
pub price: Option<Decimal>,
pub new_client_order_id: Option<String>,
pub new_order_resp_type: Option<SorOrderPlaceNewOrderRespTypeEnum>,
pub iceberg_qty: Option<Decimal>,
pub strategy_id: Option<i64>,
pub strategy_type: Option<i32>,
pub self_trade_prevention_mode: Option<SorOrderPlaceSelfTradePreventionModeEnum>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [sor_order_place] operation.
This struct holds all of the inputs you can pass when calling
sor_order_place.
Fields
symbol: StringThe symbol parameter.
This field is **required.
side: SorOrderPlaceSideEnumBUY or SELL
This field is **required.
type: SorOrderPlaceTypeEnumOnly LIMIT and MARKET orders are supported.
This field is **required.
quantity: DecimalThe quantity parameter.
This field is **required.
id: Option<String>Client-generated request identifier.
This field is **optional.
time_in_force: Option<SorOrderPlaceTimeInForceEnum>Applicable only to LIMIT order type.
This field is **optional.
price: Option<Decimal>The price parameter.
This field is **optional.
new_client_order_id: Option<String>A unique id among open orders. Automatically generated if not sent.
Orders with the same newClientOrderID can be accepted only when the previous one is filled, otherwise the order will be rejected.
This field is **optional.
new_order_resp_type: Option<SorOrderPlaceNewOrderRespTypeEnum>Set the response JSON. ACK, RESULT, or FULL. Default to FULL
This field is **optional.
iceberg_qty: Option<Decimal>Used with LIMIT to create an iceberg order.
This field is **optional.
strategy_id: Option<i64>The strategy_id parameter.
This field is **optional.
strategy_type: Option<i32>The value cannot be less than 1000000.
This field is **optional.
self_trade_prevention_mode: Option<SorOrderPlaceSelfTradePreventionModeEnum>The allowed enums is dependent on what is configured on the symbol. The possible supported values are: STP Modes.
This field is **optional.
recv_window: Option<Decimal>Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl SorOrderPlaceParams
impl SorOrderPlaceParams
Sourcepub fn builder(
symbol: String,
side: SorOrderPlaceSideEnum,
type: SorOrderPlaceTypeEnum,
quantity: Decimal,
) -> SorOrderPlaceParamsBuilder
pub fn builder( symbol: String, side: SorOrderPlaceSideEnum, type: SorOrderPlaceTypeEnum, quantity: Decimal, ) -> SorOrderPlaceParamsBuilder
Create a builder for [sor_order_place].
Required parameters:
symbol— Stringside—BUYorSELLr#type— OnlyLIMITandMARKETorders are supported.quantity—rust_decimal::Decimal