pub struct SorOrderTestParams {Show 15 fields
pub symbol: String,
pub side: SorOrderTestSideEnum,
pub type: SorOrderTestTypeEnum,
pub quantity: Decimal,
pub id: Option<String>,
pub compute_commission_rates: Option<bool>,
pub time_in_force: Option<SorOrderTestTimeInForceEnum>,
pub price: Option<Decimal>,
pub new_client_order_id: Option<String>,
pub new_order_resp_type: Option<SorOrderTestNewOrderRespTypeEnum>,
pub iceberg_qty: Option<Decimal>,
pub strategy_id: Option<i64>,
pub strategy_type: Option<i32>,
pub self_trade_prevention_mode: Option<SorOrderTestSelfTradePreventionModeEnum>,
pub recv_window: Option<Decimal>,
}Expand description
Request parameters for the [sor_order_test] operation.
This struct holds all of the inputs you can pass when calling
sor_order_test.
Fields
symbol: StringThe symbol parameter.
This field is **required.
side: SorOrderTestSideEnumThe side parameter.
This field is **required.
type: SorOrderTestTypeEnumThe r#type parameter.
This field is **required.
quantity: DecimalThe quantity parameter.
This field is **required.
id: Option<String>Unique WebSocket request ID.
This field is **optional.
compute_commission_rates: Option<bool>Default: false
See Commissions FAQ to learn more.
This field is **optional.
time_in_force: Option<SorOrderTestTimeInForceEnum>The time_in_force parameter.
This field is **optional.
price: Option<Decimal>The price parameter.
This field is **optional.
new_client_order_id: Option<String>The new client order ID for the order after being amended.
If not sent, one will be randomly generated.
It is possible to reuse the current clientOrderId by sending it as the newClientOrderId.
This field is **optional.
new_order_resp_type: Option<SorOrderTestNewOrderRespTypeEnum>The new_order_resp_type parameter.
This field is **optional.
iceberg_qty: Option<Decimal>The iceberg_qty parameter.
This field is **optional.
strategy_id: Option<i64>Arbitrary numeric value identifying the order within an order strategy.
This field is **optional.
strategy_type: Option<i32>Arbitrary numeric value identifying the order strategy. Values smaller than 1000000 are reserved and cannot be used.
This field is **optional.
self_trade_prevention_mode: Option<SorOrderTestSelfTradePreventionModeEnum>The self_trade_prevention_mode parameter.
This field is **optional.
recv_window: Option<Decimal>The value cannot be greater than 60000.
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.
Implementations
Sourceimpl SorOrderTestParams
impl SorOrderTestParams
Sourcepub fn builder(
symbol: String,
side: SorOrderTestSideEnum,
type: SorOrderTestTypeEnum,
quantity: Decimal,
) -> SorOrderTestParamsBuilder
pub fn builder( symbol: String, side: SorOrderTestSideEnum, type: SorOrderTestTypeEnum, quantity: Decimal, ) -> SorOrderTestParamsBuilder
Create a builder for [sor_order_test].
Required parameters:
symbol— Stringside— Stringr#type— Stringquantity—rust_decimal::Decimal