pub struct SorOrderTestParamsBuilder { /* private fields */ }Expand description
Builder for SorOrderTestParams.
Implementations
Sourceimpl SorOrderTestParamsBuilder
impl SorOrderTestParamsBuilder
Sourcepub fn symbol<VALUE: Into<String>>(self, value: VALUE) -> Self
pub fn symbol<VALUE: Into<String>>(self, value: VALUE) -> Self
The symbol parameter.
This field is **required.
Sourcepub fn side<VALUE: Into<SorOrderTestSideEnum>>(self, value: VALUE) -> Self
pub fn side<VALUE: Into<SorOrderTestSideEnum>>(self, value: VALUE) -> Self
Please see Enums for supported values.
This field is **required.
Sourcepub fn type<VALUE: Into<SorOrderTestTypeEnum>>(self, value: VALUE) -> Self
pub fn type<VALUE: Into<SorOrderTestTypeEnum>>(self, value: VALUE) -> Self
Please see Enums for supported values.
This field is **required.
Sourcepub fn quantity<VALUE: Into<Decimal>>(self, value: VALUE) -> Self
pub fn quantity<VALUE: Into<Decimal>>(self, value: VALUE) -> Self
The quantity parameter.
This field is **required.
Sourcepub fn id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
pub fn id<VALUE: Into<Option<String>>>(self, value: VALUE) -> Self
Client-generated request identifier.
This field is **optional.
Sourcepub fn compute_commission_rates<VALUE: Into<Option<bool>>>(
self,
value: VALUE,
) -> Self
pub fn compute_commission_rates<VALUE: Into<Option<bool>>>( self, value: VALUE, ) -> Self
Default: false
This field is **optional.
Sourcepub fn time_in_force<VALUE: Into<Option<SorOrderTestTimeInForceEnum>>>(
self,
value: VALUE,
) -> Self
pub fn time_in_force<VALUE: Into<Option<SorOrderTestTimeInForceEnum>>>( self, value: VALUE, ) -> Self
Please see Enums for supported values.
This field is **optional.
Sourcepub fn price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn price<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
The price parameter.
This field is **optional.
Sourcepub fn new_client_order_id<VALUE: Into<Option<String>>>(
self,
value: VALUE,
) -> Self
pub fn new_client_order_id<VALUE: Into<Option<String>>>( self, value: VALUE, ) -> Self
A unique id among open orders. Automatically generated if not sent. Orders with the same newClientOrderID can be accepted only when the previous one is filled, otherwise the order will be rejected.
This field is **optional.
Sourcepub fn new_order_resp_type<VALUE: Into<Option<SorOrderTestNewOrderRespTypeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn new_order_resp_type<VALUE: Into<Option<SorOrderTestNewOrderRespTypeEnum>>>( self, value: VALUE, ) -> Self
Set the response JSON. ACK, RESULT, or FULL. Default to FULL.
This field is **optional.
Sourcepub fn iceberg_qty<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn iceberg_qty<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
Used with LIMIT to create an iceberg order.
This field is **optional.
Sourcepub fn strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
pub fn strategy_id<VALUE: Into<Option<i64>>>(self, value: VALUE) -> Self
The strategy_id parameter.
This field is **optional.
Sourcepub fn strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
pub fn strategy_type<VALUE: Into<Option<i32>>>(self, value: VALUE) -> Self
The value cannot be less than 1000000.
This field is **optional.
Sourcepub fn self_trade_prevention_mode<VALUE: Into<Option<SorOrderTestSelfTradePreventionModeEnum>>>(
self,
value: VALUE,
) -> Self
pub fn self_trade_prevention_mode<VALUE: Into<Option<SorOrderTestSelfTradePreventionModeEnum>>>( self, value: VALUE, ) -> Self
The allowed enums is dependent on what is configured on the symbol. Supported values: STP Modes
This field is **optional.
Sourcepub fn recv_window<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
pub fn recv_window<VALUE: Into<Option<Decimal>>>(self, value: VALUE) -> Self
Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
This field is **optional.